<?php
/**
 * Phire CMS
 *
 * LICENSE
 *
 * This source file is subject to the new BSD license that is bundled
 * with this package in the file LICENSE.TXT.
 * It is also available through the world-wide-web at this URL:
 * http://www.phirecms.org/LICENSE.TXT
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to info@phirecms.org so we can send you a copy immediately.
 *
 * @category   Phire
 * @package    Phire_Dirs
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 */

/**
 * Phire_Dirs
 *
 * @category   Phire
 * @package    Phire_Dirs
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 * @version    1.1.2
 */

class Phire_Dirs
{

    /**
     * Determine whether or not the necessary system directories are writable or not.
     *
     * @param  string  $docroot
     * @param  boolean $msgs
     * @return boolean|array
     */
    public static function writable($docroot, $msgs = false)
    {

        $lang = new Phire_Language();

        $dirs = array(BASE_PATH . CONTENT_PATH . '/cache/',
                      BASE_PATH . CONTENT_PATH . '/assets/files/',
                      BASE_PATH . CONTENT_PATH . '/assets/images/',
                      BASE_PATH . CONTENT_PATH . '/assets/images/large/',
                      BASE_PATH . CONTENT_PATH . '/assets/images/medium/',
                      BASE_PATH . CONTENT_PATH . '/assets/images/small/',
                      BASE_PATH . CONTENT_PATH . '/extensions/themes/',
                      BASE_PATH . CONTENT_PATH . '/extensions/plugins/');

        $errorMsgs = array();
        $errors = 0;

        // Check if the necessary directories are writable for IIS.
        if (stripos($_SERVER['SERVER_SOFTWARE'], 'iis') !== false) {
            foreach ($dirs as $value) {
                touch($docroot . $value . 'writetest.txt');
                clearstatcache();
                if (!file_exists($docroot . $value . 'writetest.txt')) {
                    $errors++;
                    $errorMsgs[] = "        <p style=\"width: 95%; margin: 0 auto; padding: 5px 0 10px 0;\">" . $lang->__('The directory %1 is not writable. Please make it writable to continue.', "<strong style=\"color: #008aff;\">{$value}</strong>") . "</p>\n";
                } else {
                    unlink($docroot . $value . 'writetest.txt');
                }
            }
        // Check if the necessary directories are writable for Unix/Linux.
        } else {
            foreach ($dirs as $value) {
                clearstatcache();
                if (!is_writable($docroot . $value)) {
                    $errors++;
                    $errorMsgs[] = "        <p style=\"width: 95%; margin: 0 auto; padding: 5px 0 10px 0;\">" . $lang->__('The directory %1 is not writable. Please make it writable to continue.', "<strong style=\"color: #008aff;\">{$value}</strong>") . "</p>\n";
                }
            }
        }

        // If the messaging flag was passed, return any error messages, else return true/false.
        if ($msgs) {
            return $errorMsgs;
        } else {
            return ($errors == 0) ? true : false;
        }

    }

}
