<?php
/**
 * Phire CMS
 *
 * LICENSE
 *
 * This source file is subject to the new BSD license that is bundled
 * with this package in the file LICENSE.TXT.
 * It is also available through the world-wide-web at this URL:
 * http://www.phirecms.org/LICENSE.TXT
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to info@phirecms.org so we can send you a copy immediately.
 *
 * @category   Phire
 * @package    Phire_Error
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 */

/**
 * Phire_Error
 *
 * @category   Phire
 * @package    Phire_Error
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 * @version    1.1.2
 */

class Phire_Error extends Phire_Template
{

    /**
     * Error message
     * @var string
     */
    protected $_error_msg = null;

    /**
     * Error type
     * @var string
     */
    protected $_error_type = null;

    /**
     * Site object
     * @var Phire_Table_Site
     */
    protected $_site = null;

    /**
     * Constructor
     *
     * Instantiate the error object.
     *
     * @param  Exception $ex
     * @return void
     */
    public function __construct($ex)
    {

        parent::__construct();

        $lang = new Phire_Language();
        $error_file = new Moc10_File($ex->getFile());

        $this->_error_type = ucfirst($error_file->filename) . ' ' . $lang->__('Error');
        $this->_error_msg = "        <h2 class=\"redHeader\">" . $this->_error_type . "</h2>\n        <p>" . $ex->getMessage() . "</p>";

        // Get the site information.
        $this->_site = new Phire_Table_Sites();
        $this->_site->getSite();

        $this->setContent('[{page_charset}]', $this->_site->charset);
        $this->setContent('[{page_author}]', Moc10_String::setString($this->_site->default_author)->strip()->html());
        $this->setContent('[{page_keywords}]', Moc10_String::setString($this->_site->default_keywords)->strip()->html());
        $this->setContent('[{page_desc}]', Moc10_String::setString($this->_site->default_desc)->strip()->html());
        $this->setContent('[{page_robots}]', $this->_site->robots);
        $this->setContent('[{site_domain}]', $this->_site->site_domain);
        $this->setContent('[{base_path}]', BASE_PATH);
        $this->setContent('[{sys_path}]', SYS_PATH);
        $this->setContent('[{content_path}]', CONTENT_PATH);

    }

    /**
     * Initialize the error template.
     *
     * @return void
     */
    public function init()
    {

        $this->setContent('[{page_title}]', Moc10_String::setString($this->_site->default_title . $this->_site->title_separator . $this->_error_type)->strip()->html());
        $this->setContent('[{page_content}]', $this->_error_msg);
        $this->setContent('[{page_sub_title}]', "<span style=\"color: #f00;\">" . $this->_error_type . "</span>");

    }

}
