<?php
/**
 * Phire CMS
 *
 * LICENSE
 *
 * This source file is subject to the new BSD license that is bundled
 * with this package in the file LICENSE.TXT.
 * It is also available through the world-wide-web at this URL:
 * http://www.phirecms.org/LICENSE.TXT
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to info@phirecms.org so we can send you a copy immediately.
 *
 * @category   Phire
 * @package    Phire_Event
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 */

/**
 * Phire_Event
 *
 * @category   Phire
 * @package    Phire_Event
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 * @version    1.1.2
 */

class Phire_Event extends Phire_Template
{

    /**
     * Event ID
     * @var string
     */
    protected $_event_id = null;

    /**
     * Event type ID
     * @var string
     */
    protected $_event_type_id = null;

    /**
     * Site object
     * @var Phire_Table_Site
     */
    protected $_site = null;

    /**
     * Constructor
     *
     * Instantiate the event object.
     *
     * @param  string $url
     * @return void
     */
    public function __construct($url)
    {

        parent::__construct();
        $this->_tmpl = Phire_Parser::getParser($this->_tmpl, $url)->getContent();

        $urlParts = Moc10_String::setString($url)->split('/');

        if ($urlParts[1] == 'events') {
            $this->_event_type_id = (isset($urlParts[2])) ? $urlParts[2] : null;
        } else {
            $this->_event_id = (isset($urlParts[2])) ? $urlParts[2] : null;
        }

        // Get the site information.
        $this->_site = new Phire_Table_Sites();
        $this->_site->getSite();

        $this->setContent('[{page_charset}]', $this->_site->charset);
        $this->setContent('[{page_author}]', Moc10_String::setString($this->_site->default_author)->strip()->html());
        $this->setContent('[{page_keywords}]', Moc10_String::setString($this->_site->default_keywords)->strip()->html());
        $this->setContent('[{page_desc}]', Moc10_String::setString($this->_site->default_desc)->strip()->html());
        $this->setContent('[{page_robots}]', $this->_site->robots);
        $this->setContent('[{site_domain}]', $this->_site->site_domain);
        $this->setContent('[{base_path}]', BASE_PATH);
        $this->setContent('[{sys_path}]', SYS_PATH);
        $this->setContent('[{content_path}]', CONTENT_PATH);

    }

    /**
     * Initialize the event template.
     *
     * @return void
     */
    public function init()
    {

        $lang = new Phire_Language();
        $sess = Moc10_Session::getInstance();

        $date_format = $this->_site->default_date_format;
        $time_format = ($this->_site->default_time_format != '') ? ' ' . $this->_site->default_time_format : 'g:i A';

        // If no event is found, display error.
        if (is_null($this->_event_type_id) && is_null($this->_event_id)) {

            $this->setContent('[{page_title}]', Moc10_String::setString($this->_site->default_title . $this->_site->title_separator . $lang->__('Event') . " > " . $lang->__('Error'))->strip()->html());
            $this->setContent('[{page_sub_title}]', $lang->__('Event') . " &gt; " . $lang->__('Error'));
            $this->setContent('[{page_content}]', "<!-- Event Results Begin Here //-->\n        <div id=\"eventContent\">\n            <p><strong>" . $lang->__('That event or event type was not found.') . "</strong></p>\n        </div>\n<!-- Event Results End Here //-->");

        // Else, perform the event search.
        } else {

            // If it's an event type listing.
            if (!is_null($this->_event_type_id)) {

                $events = new Phire_Table_Events();
                if (isset($_GET['year'])) {
                    $events->execute("SELECT * from " . DB_PREFIX . "events WHERE type_id = '" . $this->_event_type_id . "' AND event_start_date LIKE '" . (string)Moc10_String::setString($_GET['year'])->escape(true)->striptags() . "-%' AND site_id = '" . $this->_site->site_id . "' ORDER BY event_start_date ASC");
                } else {
                    $events->execute("SELECT * from " . DB_PREFIX . "events WHERE type_id = '" . $this->_event_type_id . "' AND site_id = '" . $this->_site->site_id . "' ORDER BY event_start_date ASC");
                }
                $event_type = new Phire_Table_EventTypes();
                $event_type->findById($this->_event_type_id);

                // If no events of that type are found.
                if (!isset($events->rows[0])) {
                    $this->setContent('[{page_title}]', Moc10_String::setString($this->_site->default_title . $this->_site->title_separator . $lang->__('Event') . " > " . $lang->__('Error'))->strip()->html());
                    $this->setContent('[{page_sub_title}]', $lang->__('Event') . " &gt; " . $lang->__('Error'));
                    $this->setContent('[{page_content}]', "<!-- Event Results Begin Here //-->\n        <div id=\"eventContent\">\n            <p><strong>" . $lang->__('That event type was not found.') . "</strong></p>\n        </div>\n<!-- Event Results End Here //-->");
                // Else, if event type is private.
                } else if (($event_type->event_type_access == 'Private') && (!isset($sess->member_id)) && (!isset($sess->user_id))) {
                    header('Location: /member/login');
                // Else, format and render events listing.
                } else {

                    $this->setContent('[{page_title}]', Moc10_String::setString($this->_site->default_title . $this->_site->title_separator . $event_type->event_type)->strip()->html());
                    $this->setContent('[{page_sub_title}]', $event_type->event_type);
                    $event_format = '';

                    foreach ($events->rows as $event) {
                        if ($event->event_start_date != '0000-00-00') {
                            $event_start_date = Moc10_String::setString($event->event_start_date)->date($date_format);
                        } else {
                            $rec = Moc10_String::setString($event->event_recurrence)->split('+');
                            $event_start_date = $rec[0] . ' ' . $rec[1] . ' ' . $rec[2];
                        }
                        if ($event->event_end_date != '0000-00-00') {
                            $event_format .= "        <div class=\"eventDiv\"><a class=\"eventLink\" href=\"/event/{$event->event_id}" . (string)Moc10_String::setString($event->event_title)->slug() . "\">{$event->event_title}</a><br />" . $event_start_date . " - " . Moc10_String::setString($event->event_end_date)->date($date_format);
                        } else {
                            $event_format .= "        <div class=\"eventDiv\"><a class=\"eventLink\" href=\"/event/{$event->event_id}" . (string)Moc10_String::setString($event->event_title)->slug() . "\">{$event->event_title}</a><br />" . $event_start_date;
                        }
                        if ($event->event_end_time != '00:00:00') {
                            $event_format .= ", " . Moc10_String::setString($event->event_start_time)->date($time_format) . " to " . Moc10_String::setString($event->event_end_time)->date($time_format);
                        } else {
                            $event_format .= ", " . Moc10_String::setString($event->event_start_time)->date($time_format);
                        }
                        if (isset($_GET['display'])) {
                            $dispAry = explode('|', $_GET['display']);
                            if (in_array('address', $dispAry)) {
                                if ($event->address1 != '') {
                                    $event_format .= "<br />" . $event->address1;
                                }
                                if ($event->address2 != '') {
                                    $event_format .= "<br />" . $event->address2;
                                }
                                if (($event->city != '') && ($event->state != '') && ($event->state != '--') && ($event->zip != '')) {
                                    $event_format .= "<br />" . $event->city . ", " . $event->state . " " . $event->zip;
                                } else if (($event->city != '') && ($event->state != '') && ($event->state != '--')) {
                                    $event_format .= "<br />" . $event->city . ", " . $event->state;
                                } else if ($event->city != '') {
                                    $event_format .= "<br />" . $event->city;
                                }
                                if (($event->country != '--') && ($event->country != '')) {
                                    $event_format .= "<br />" . $event->country;
                                }
                                if ($event->phone != '') {
                                    $event_format .= "<br />" . $event->phone;
                                }
                            }
                            if (in_array('link', $dispAry)) {
                                if ($event->event_link != '') {
                                    $link_type = (stripos($event->event_link, 'map') !== false) ?  $lang->__('Map') : $lang->__('Event');
                                    $event_format .= "<br /><a class=\"mapLink\" href=\"" . $event->event_link . "\">{$link_type} " . $lang->__('Link') . "</a>";
                                }
                            }
                        }
                        $event_format .= "</div>\n";
                    }

                    $this->setContent('[{page_content}]', $event_format);

                }

            // Else, if it's a single event listing.
            } else if (!is_null($this->_event_id)) {

                $event = new Phire_Table_Events();
                $event->findById($this->_event_id);

                // If event is not found or is not assigned to the current site.
                if (!isset($event->event_id) || ($event->site_id != $this->_site->site_id)) {
                    $this->setContent('[{page_title}]', Moc10_String::setString($this->_site->default_title . $this->_site->title_separator . $lang->__('Event') . " > " . $lang->__('Error'))->strip()->html());
                    $this->setContent('[{page_sub_title}]', $lang->__('Event') . " &gt; " . $lang->__('Error'));
                    $this->setContent('[{page_content}]', "<!-- Event Results Begin Here //-->\n        <div id=\"eventContent\">\n            <p><strong>" . $lang->__('That event was not found.') . "</strong></p>\n        </div>\n<!-- Event Results End Here //-->");
                // Else, if event is set to private.
                } else if (($event->event_access == 'Private') && (!isset($sess->member_id)) && (!isset($sess->user_id))) {
                    header('Location: /member/login');
                // Else, format and render event.
                } else {

                    $this->setContent('[{page_title}]', Moc10_String::setString($this->_site->default_title . $this->_site->title_separator . $event->event_title)->strip()->html());
                    $this->setContent('[{page_sub_title}]', $event->event_title);
                    $event_format = '';

                    if ($event->event_start_date != '0000-00-00') {
                        $event_start_date = Moc10_String::setString($event->event_start_date)->date($date_format);
                    } else {
                        $rec = Moc10_String::setString($event->event_recurrence)->split('+');
                        $event_start_date = $rec[0] . ' ' . $rec[1] . ' ' . $rec[2];
                    }

                    if ($event->event_end_date != '0000-00-00') {
                        $event_format .= "        <div class=\"eventDiv\">\n            " . $event_start_date . " - " . Moc10_String::setString($event->event_end_date)->date($date_format);
                    } else {
                        $event_format .= "        <div class=\"eventDiv\">\n            " . $event_start_date;
                    }

                    if ($event->event_end_time != '00:00:00') {
                        $event_format .= ", " . Moc10_String::setString($event->event_start_time)->date($time_format) . " to " . Moc10_String::setString($event->event_end_time)->date($time_format);
                    } else {
                        $event_format .= ", " . Moc10_String::setString($event->event_start_time)->date($time_format);
                    }

                    $evt_info = '';
                    if ($event->address1 != '') {
                        $evt_info .= "                " . $event->address1 . "<br />\n";
                    }
                    if ($event->address2 != '') {
                        $evt_info .= "                " . $event->address2 . "<br />\n";
                    }
                    if (($event->city != '') && ($event->state != '') && ($event->state != '--') && ($event->zip != '')) {
                        $evt_info .= "                " . $event->city . ", " . $event->state . " " . $event->zip . "<br />\n";
                    } else if (($event->city != '') && ($event->state != '') && ($event->state != '--')) {
                        $evt_info .= "                " . $event->city . ", " . $event->state . "<br />\n";
                    } else if ($event->city != '') {
                        $evt_info .= "                " . $event->city . "<br />\n";
                    }
                    if (($event->country != '--') && ($event->country != '')) {
                        $evt_info .= "                " . $event->country . "<br />\n";
                    }
                    if ($event->phone != '') {
                        $evt_info .= "                " . $event->phone . "<br />\n";
                    }
                    if ($event->event_link != '') {
                        $link_type = (stripos($event->event_link, 'map') !== false) ? $lang->__('Map') : $lang->__('Event');
                        $evt_info .= "                <a class=\"mapLink\" href=\"" . $event->event_link . "\">{$link_type} " . $lang->__('Link') . "</a><br />\n";
                    }

                    if ($evt_info != '') {
                        $event_format .= "\n            <div class=\"eventInfo\">\n" . $evt_info . "            </div>";
                    }

                    $event_desc = ($event->event_desc_format == 'Text') ? (string)Moc10_String::setString($event->event_desc)->links(true)->br() : $event->event_desc;

                    $event_format .= "\n            <h4>" . $lang->__('Event Description:') . "</h4>\n            <p>\n                " . $event_desc . "\n            </p>\n        </div>\n";
                    $this->setContent('[{page_content}]', $event_format);

                }

            }

        }

    }

}
