<?php
/**
 * Phire CMS
 *
 * LICENSE
 *
 * This source file is subject to the new BSD license that is bundled
 * with this package in the file LICENSE.TXT.
 * It is also available through the world-wide-web at this URL:
 * http://www.phirecms.org/LICENSE.TXT
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to info@phirecms.org so we can send you a copy immediately.
 *
 * @category   Phire
 * @package    Phire_Form
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 */

/**
 * Phire_Form_AddImage
 *
 * @category   Phire
 * @package    Phire_Form
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 * @version    1.1.2
 */

class Phire_Form_AddImage extends Moc10_Form
{

    /**
     * Form templates
     * @var array
     */
    protected $_templates = array('main' => null, 'mobile' => null, 'zip' => null);

    /**
     * $_POST fields
     * @var array
     */
    protected $_postFields = array('plugin' => null,
                                   'site_id' => null,
                                   'section_id' => null,
                                   'image_name_1' => null,
                                   'image_title_1' => null,
                                   'image_caption_1' => null,
                                   'mobile' => null,
                                   'image_id' => 0);

    /**
     * Initialization method for the add image form.
     *
     * @param  array $post
     * @param  string $img_nme
     * @return void
     */
    public function init($post = null, $img_nme = null)
    {

        $lang = new Phire_Language();

        $this->_setFields($post, $img_nme);
        $this->_setTemplates();

        $this->setAttributes('id', 'addImageForm');
        $this->setAttributes('enctype', 'multipart/form-data');

        $sitesAry = Phire_Sites::getAllowedSites(true);

        // Get sections.
        $sects = new Phire_Table_Sections();
        if ($this->_postFields['site_id'] == 0) {
            $sects->findAll('section_id ASC', 'site_id', $sitesAry['first_site_id']);
        } else {
            $sects->findAll('section_id ASC', 'site_id', $this->_postFields['site_id']);
        }
        $sectAry = array('0' => '(' . $lang->__('None') . ')');
        if (isset($sects->rows[0])) {
            foreach ($sects->rows as $sect) {
                $sectAry[$sect->section_id] = $sect->section_title;
            }
        }

        // Create the 'section_id' form element.
        $section_id = new Moc10_Form_Element_Select('section_id', $sectAry, $this->_postFields['section_id']);
        $section_id->setLabel($lang->__('Section:'));

        $brws = new Moc10_Session_Browser();
        $fileClass = ($brws->browser == 'MSIE') ? 'fileInputIE' : 'fileInput';

        // Create the 'image_name_1' form element.
        $image_name_1 = new Moc10_Form_Element('file', 'image_name_1', $this->_postFields['image_name_1']);
        $image_name_1->setLabel($lang->__('Image Name:'));
        $image_name_1->setAttributes('size', ((!is_null($this->_postFields['mobile'])) ? '25' : '35'));
        $image_name_1->setAttributes('class', $fileClass);

        // Create the 'image_title_1' form element.
        $image_title_1 = new Moc10_Form_Element('text', 'image_title_1', $this->_postFields['image_title_1']);
        $image_title_1->setLabel($lang->__('Image Title:'));
        $image_title_1->setAttributes('size', ((!is_null($this->_postFields['mobile'])) ? '25' : '45'));

        // Create the 'image_caption_1' form element.
        $image_caption_1 = new Moc10_Form_Element('text', 'image_caption_1', $this->_postFields['image_caption_1']);
        $image_caption_1->setLabel($lang->__('Image Caption:'));
        $image_caption_1->setAttributes('size', ((!is_null($this->_postFields['mobile'])) ? '25' : '70'));

        // Create the 'image_batch_upload' form element.
        $image_batch_upload = new Moc10_Form_Element('file', 'image_batch_upload', null);
        $image_batch_upload->setLabel('Batch Image Upload:');
        $image_batch_upload->setAttributes('size', '50');
        $image_batch_upload->setAttributes('class', $fileClass);

        // Create the 'submit' form element.
        $submit = new Moc10_Form_Element('submit', 'submit', $lang->__('SAVE'));
        $submit->setAttributes('style', 'float: right;');

        // Set whether it's a mobile form template or not.
        if (!is_null($this->_postFields['mobile'])) {
            $sess = Moc10_Session::getInstance();
            $submit->setAttributes('class', 'submitBtn');
            $site_id = new Moc10_Form_Element('hidden', 'site_id', $sess->cur_site_id);
            $this->setTemplate($this->_templates['mobile']);
        } else {
            $this->setAttributes('onsubmit', "return addImageFrm.imageValidate();");
            $site_id = new Moc10_Form_Element_Select('site_id', $sitesAry['sites'], $this->_postFields['site_id']);
            $site_id->setLabel($lang->__('Add to Site:'));
            $submit->setAttributes('class', 'submitBtn');
            $site_id->setAttributes('onchange', "xmlhttp.getRequest('../core/process/check.section.php?site_id=' + this.value, addImageFrm.changeSection); return false;");
            $tmpl = '';
            if (class_exists('ZipArchive')) {
                $tmpl = str_replace('[{zip_tmpl}]', $this->_templates['zip'], $this->_templates['main']);
            } else {
                $tmpl = str_replace('[{zip_tmpl}]', '', $this->_templates['main']);
                $this->addElements(array($site_id, $section_id, $image_name_1, $image_title_1, $image_caption_1, $submit));
            }
            $this->setTemplate($tmpl);
        }

        $elems = array($site_id, $section_id, $image_name_1, $image_title_1, $image_caption_1, $submit);
        if ((is_null($this->_postFields['mobile'])) && (class_exists('ZipArchive'))) {
            $elems[] = $image_batch_upload;
        }

        // Add the form element objects to the form.
        $this->addElements($elems);

    }

    /**
     * Method to set the form templates.
     *
     * @return void
     */
    protected function _setTemplates()
    {

        $lang = new Phire_Language();

        if (!is_null($this->_postFields['plugin'])) {
            $plugin = "<input type=\"hidden\" name=\"plugin\" value=\"{$this->_postFields['plugin']}\" />";
            $plg_lnk = BASE_PATH . CONTENT_PATH . "/extensions/plugins/{$this->_postFields['plugin']}/?sys_path=" . BASE_PATH . SYS_PATH;
            $plg_cancel = "&plugin={$this->_postFields['plugin']}";
        } else {
            $plugin = null;
            $plg_lnk = './images.php';
            $plg_cancel = null;
        }


        $back = $lang->__('Back');
        $blue = $lang->__('Blue fields are required.');
        $donot_wrap = wordwrap($lang->__('Once you click save, DO NOT leave the page until the images have finished processing.'), 80, "<br />");
        $donot = $lang->__('Once you click save, DO NOT leave the page until the images have finished processing.');
        $cancel = $lang->__('CANCEL');

        // Define the main form template.
        $this->_templates['main'] = <<<FORMTEMP
            <table id="headerTable" cellpadding="0" cellspacing="0"><tr><td>&lt;&lt;&lt; <a class="orangeLink" href="{$plg_lnk}">{$back}</a></td></tr></table>
            <table id="dataAltTable" cellspacing="0" cellpadding="0">
                <tr class="grayHeader">
                    <td class="grayHeader">
                        &nbsp;
                    </td>
                </tr>
                <tr>
                    <td style="padding: 15px;">
                        <table id="entryTable" cellspacing="0" cellpadding="0">
                            <tr>
                                <td>
                                    <h4>{$blue}</h4>
                                </td>
                                <td class="textRight" colspan="2">
                                    [{site_id_label}]
                                    [{site_id}]
                                    <span style="padding: 0 10px 0 10px;"> </span>
                                    [{section_id_label}]
                                    <span id="sectionDiv">
                                        [{section_id}]
                                    </span>
                                </td>
                                <td>
                                    &nbsp;
                                </td>
                            </tr>
                            <tr>
                                <td>
                                    [{image_name_1_label}]
                                </td>
                                <td>
                                    [{image_title_1_label}]
                                </td>
                                <td>
                                    [{image_caption_1_label}]
                                </td>
                                <td>
                                    &nbsp;
                                </td>
                            </tr>
                            <tr>
                                <td id="imageNameTD" style="vertical-align: top;">
                                    [{image_name_1}]
                                </td>
                                <td id="imageTitleTD" style="vertical-align: top;">
                                    [{image_title_1}]
                                </td>
                                <td id="imageCaptionTD" style="vertical-align: top;">
                                    [{image_caption_1}]
                                </td>
                                <td style="vertical-align: top;">
                                    <a href="#" onclick="addImageFrm.addImageInput(); return false;">[+]</a>
                                </td>
                            </tr>[{zip_tmpl}]
                            <tr>
                                <td colspan="3">
                                    <strong style="float: left; color: #f00;">{$donot_wrap}</strong><a style="margin: 0 0 0 10px; padding-top: 6px; height: 19px; font-size: 0.825em; float: right;" class="submitGrayBtn" href="../core/process/add.images.php?action=cancel{$plg_cancel}">{$cancel}</a> [{submit}] {$plugin}
                                </td>
                                <td>
                                    &nbsp;
                                </td>
                            </tr>
                        </table>
                        <script type="text/javascript">
                            addImageFormInit();
                            var xmlhttp = new JaxXmlHttp();
                        </script>
                    </td>
                </tr>
            </table>
FORMTEMP;

        $mobile = (!is_null($this->_postFields['mobile'])) ? "<input type=\"hidden\" name=\"mobile\" value=\"true\" />" : null;

        // Define the mobile form template.
        $this->_templates['mobile'] = <<<FORMTEMP
            <table id="headerTable" cellpadding="0" cellspacing="0"><tr><td>&lt;&lt;&lt; <a class="orangeLink" href="./images.php">{$back}</a></td></tr></table>
            <table id="dataAltTable" cellspacing="0" cellpadding="0">
                <tr class="grayHeader" style="height; 16px;">
                    <td class="grayHeader" style="height; 16px;">
                        &nbsp;
                    </td>
                </tr>
                <tr>
                    <td style="padding: 5px;">
                        <table id="entryTable" cellspacing="0" cellpadding="0">
                            <tr>
                                <td>
                                    &nbsp;
                                </td>
                                <td>
                                    <h4>{$blue}</h4>
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight">
                                    [{section_id_label}]
                                </td>
                                <td>
                                    [{section_id}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight">
                                    [{image_name_1_label}]
                                </td>
                                <td id="imageNameTD" style="vertical-align: top;">
                                    [{image_name_1}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight">
                                    [{image_title_1_label}]
                                </td>
                                <td id="imageTitleTD" style="vertical-align: top;">
                                    [{image_title_1}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight">
                                    [{image_caption_1_label}]
                                </td>
                                <td id="imageCaptionTD" style="vertical-align: top;">
                                    [{image_caption_1}]
                                </td>
                            </tr>
                            <tr>
                                <td colspan="2">
                                    <strong style="color: #f00;">{$donot}</strong><br /><br />
                                    <a style="float: right; margin: 0 0 0 5px; padding: 2px 3px 4px 3px; height: 10px; font-size: 0.9em;" class="submitBtnGray" href="../../core/process/add.images.php?action=cancel&mobile=true">{$cancel}</a> [{submit}] {$mobile} [{site_id}]
                                </td>
                            </tr>
                        </table>
                    </td>
                </tr>
            </table>
FORMTEMP;

        $zipmsg = $lang->__('Or, you can upload a ZIP file of images that can be processed all at once, with their titles and captions created from the image file names.');
        $zipnote = $lang->__('NOTE: The ZIP file must be a direct archive of the images and should not contain any folders or subfolders.');

        // Define the zip form template.
        $this->_templates['zip'] = <<<ZIPTMPL

                            <tr>
                                <td colspan="4">
                                    <br /><br />
                                </td>
                            </tr>
                            <tr>
                                <td colspan="3" style="border-top: solid 1px #aaa; border-bottom: solid 1px #aaa;">
                                    <p style="font-size: 0.85em;">
                                        {$zipmsg}<br />
                                        <strong>{$zipnote}</strong>
                                    </p>
                                    [{image_batch_upload_label}] [{image_batch_upload}]<br /><br />
                                </td>
                                <td style="border-top: solid 1px #aaa; border-bottom: solid 1px #aaa;">
                                    &nbsp;<br /><br />
                                </td>
                            </tr>
                            <tr>
                                <td colspan="4">
                                    <br />
                                </td>
                            </tr>
ZIPTMPL;

    }

    /**
     * Method to set the post fields.
     *
     * @param  array $post
     * @param  string $img_nme
     * @return void
     */
    protected function _setFields($post = null, $img_nme = null)
    {

        if (!is_null($post)) {
            foreach ($post as $key => $value) {
                if (array_key_exists($key, $this->_postFields)) {
                    $this->_postFields[$key] = (isset($post[$key])) ? $post[$key] : null;
                }
            }
            $this->_postFields['image_name_1'] = $img_nme;
        }

    }

}
