<?php
/**
 * Phire CMS
 *
 * LICENSE
 *
 * This source file is subject to the new BSD license that is bundled
 * with this package in the file LICENSE.TXT.
 * It is also available through the world-wide-web at this URL:
 * http://www.phirecms.org/LICENSE.TXT
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to info@phirecms.org so we can send you a copy immediately.
 *
 * @category   Phire
 * @package    Phire_Form
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 */

/**
 * Phire_Form_Event
 *
 * @category   Phire
 * @package    Phire_Form
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 * @version    1.1.2
 */

class Phire_Form_Event extends Moc10_Form
{

    /**
     * Form templates
     * @var array
     */
    protected $_templates = array('main' => null, 'mobile' => null);

    /**
     * $_POST fields
     * @var array
     */
    protected $_postFields = array('plugin' => null,
                                   'site_id' => 0,
                                   'type_id' => 0,
                                   'section_id' => 0,
                                   'event_title' => null,
                                   'start_month' => null,
                                   'start_day' => null,
                                   'start_year' => null,
                                   'end_month' => null,
                                   'end_day' => null,
                                   'end_year' => null,
                                   'recurrence1' => null,
                                   'recurrence2' => null,
                                   'recurrence3' => null,
                                   'start_hour' => null,
                                   'start_minute' => null,
                                   'end_hour' => null,
                                   'end_minute' => null,
                                   'address1' => null,
                                   'address2' => null,
                                   'city' => null,
                                   'state' => null,
                                   'zip' => null,
                                   'country' => null,
                                   'phone' => null,
                                   'event_link' => null,
                                   'event_desc' => null,
                                   'event_desc_format' => null,
                                   'event_access' => null,
                                   'mobile' => null,
                                   'event_id' => 0);

    /**
     * Initialization method for the event form.
     *
     * @param  array $post
     * @return void
     */
    public function init($post = null)
    {

        $lang = new Phire_Language();

        $this->_setFields($post);
        $this->_setTemplates();

        $this->setAttributes('id', 'addEventForm');

        // Get the event types.
        $types = new Phire_Table_EventTypes();
        $types->findAll('type_id ASC');
        $typeAry = array('0' => '(' . $lang->__('None') . ')');

        foreach ($types->rows as $type) {
            $typeAry[$type->type_id] = $type->event_type;
        }

        // Create the 'type_id' form element.
        $type_id = new Moc10_Form_Element_Select('type_id', $typeAry, $this->_postFields['type_id']);
        $type_id->setLabel(((!is_null($this->_postFields['mobile'])) ? $lang->__('Type:') : $lang->__('Event Type:')));

        $sitesAry = Phire_Sites::getAllowedSites(true);

        // Get sections.
        $sects = new Phire_Table_Sections();
        if ($this->_postFields['site_id'] == 0) {
            $sects->findAll('section_id ASC', 'site_id', $sitesAry['first_site_id']);
        } else {
            $sects->findAll('section_id ASC', 'site_id', $this->_postFields['site_id']);
        }
        $sectAry = array('0' => '(' . $lang->__('None') . ')');
        if (isset($sects->rows[0])) {
            foreach ($sects->rows as $sect) {
                $sectAry[$sect->section_id] = $sect->section_title;
            }
        }

        // Create the 'section_id' form element.
        $section_id = new Moc10_Form_Element_Select('section_id', $sectAry, $this->_postFields['section_id']);
        $section_id->setLabel($lang->__('Section:'));

        // Create the 'event_title' form element.
        $event_title = new Moc10_Form_Element('text', 'event_title', $this->_postFields['event_title']);
        $event_title->setLabel(((!is_null($this->_postFields['mobile'])) ? $lang->__('Title:') : $lang->__('Event Title:')));
        $event_title->setAttributes('size', ((!is_null($this->_postFields['mobile'])) ? '20' : '120'));
        $event_title->setRequired(true);

        if (is_null($this->_postFields['start_month'])) {
            $this->_postFields['start_month'] = date('m');
        }

        if (is_null($this->_postFields['start_day'])) {
            $this->_postFields['start_day'] = date('d');
        }

        if (is_null($this->_postFields['start_year'])) {
            $this->_postFields['start_year'] = date('Y');
        }

        // Create the 'start_month' form element.
        $start_month = new Moc10_Form_Element_Select('start_month', 'MONTHS_SHORT', $this->_postFields['start_month']);
        $start_month->setLabel($lang->__('Date:'));

        // Create the 'start_day' form element.
        $start_day = new Moc10_Form_Element_Select('start_day', 'DAYS_OF_MONTH', $this->_postFields['start_day']);

        // Create the 'start_year' form element.
        $start_year = new Moc10_Form_Element_Select('start_year', ('YEAR_2000_' . (date('Y') + 10)), $this->_postFields['start_year']);

        // Create the 'end_month' form element.
        $end_month = new Moc10_Form_Element_Select('end_month', 'MONTHS_SHORT', $this->_postFields['end_month']);

        // Create the 'end_day' form element.
        $end_day = new Moc10_Form_Element_Select('end_day', 'DAYS_OF_MONTH', $this->_postFields['end_day']);

        // Create the 'end_year' form element.
        $end_year = new Moc10_Form_Element_Select('end_year', ('YEAR_2000_' . (date('Y') + 10)), $this->_postFields['end_year']);

        // Create the 'recurrence1' form element.
        $recurrence1 = new Moc10_Form_Element_Select('recurrence1', array('--' => '--', '1st' => '1st', '2nd' => '2nd', '3rd' => '3rd', '4th' => '4th', '5th' => '5th', 'Last' => $lang->__('Last'), 'Every' => $lang->__('Every'), 'Every other (odd)' => $lang->__('Every other (odd)'), 'Every other (even)' => $lang->__('Every other (even)')), $this->_postFields['recurrence1']);
        $recurrence1->setLabel(((!is_null($this->_postFields['mobile'])) ? $lang->__('Recur:') : $lang->__('Or, Recurring:')));

        $days = array('--' => '------',
                      'Sunday' => $lang->__('Sunday'),
                      'Monday' => $lang->__('Monday'),
                      'Tuesday' => $lang->__('Tuesday'),
                      'Wednesday' => $lang->__('Wednesday'),
                      'Thursday' => $lang->__('Thursday'),
                      'Friday' => $lang->__('Friday'),
                      'Saturday' => $lang->__('Saturday'));

        // Create the 'recurrence2' form element.
        $recurrence2 = new Moc10_Form_Element_Select('recurrence2', $days, $this->_postFields['recurrence2']);

        // Create the 'recurrence3' form element.
        $recurrence3 = new Moc10_Form_Element_Select('recurrence3', array('of the month' => $lang->__('of the month'),  'of every other month (odd)' => $lang->__('of every other month (odd)'), 'of every other month (even)' => $lang->__('of every other month (even)')), $this->_postFields['recurrence3']);

        if ((($this->_postFields['start_month'] == '--') || ($this->_postFields['start_day'] == '--') || ($this->_postFields['start_year'] == '----')) && (($this->_postFields['recurrence1'] == '--') || ($this->_postFields['recurrence2'] == '--'))) {
            $recurrence2->addValidator('NotEqual', true, '--', $lang->__('You must set either a one-time start date or a recurring date.'));
        }

        if (is_null($this->_postFields['start_hour'])) {
            $this->_postFields['start_hour'] = date('H');
        }

        if (is_null($this->_postFields['start_minute'])) {
            $this->_postFields['start_minute'] = date('i');
        }

        // Create the 'start_hour' form element.
        $start_hour = new Moc10_Form_Element_Select('start_hour', 'MILITARY_HOURS', $this->_postFields['start_hour']);
        $start_hour->setLabel($lang->__('Time:'));
        $start_hour->addValidator('NotEqual', true, '--', $lang->__('Please select an hour.'));
        $start_hour->setRequired(true);

        // Create the 'start_minute' form element.
        $start_minute = new Moc10_Form_Element_Select('start_minute', 'MINUTES', $this->_postFields['start_minute']);
        $start_minute->addValidator('NotEqual', true, '--', $lang->__('Please select a minute.'));

        // Create the 'end_hour' form element.
        $end_hour = new Moc10_Form_Element_Select('end_hour', 'MILITARY_HOURS', $this->_postFields['end_hour']);

        // Create the 'end_minute' form element.
        $end_minute = new Moc10_Form_Element_Select('end_minute', 'MINUTES', $this->_postFields['end_minute']);

        // Create the 'address1' form element.
        $address1 = new Moc10_Form_Element('text', 'address1', $this->_postFields['address1']);
        $address1->setLabel(((!is_null($this->_postFields['mobile'])) ? $lang->__('Add 1:') : $lang->__('Address 1:')));
        $address1->setAttributes('size', ((!is_null($this->_postFields['mobile'])) ? '20' : '50'));

        // Create the 'address2' form element.
        $address2 = new Moc10_Form_Element('text', 'address2', $this->_postFields['address2']);
        $address2->setLabel(((!is_null($this->_postFields['mobile'])) ? $lang->__('Add 2:') : $lang->__('Address 2:')));
        $address2->setAttributes('size', ((!is_null($this->_postFields['mobile'])) ? '20' : '50'));

        // Create the 'city' form element.
        $city = new Moc10_Form_Element('text', 'city', $this->_postFields['city']);
        $city->setLabel($lang->__('City:'));
        $city->setAttributes('size', ((!is_null($this->_postFields['mobile'])) ? '20' : '50'));

        if ($this->_postFields['country'] == 'US') {
            // Create the 'state' form element.
            $state = new Moc10_Form_Element_Select('state', 'US_STATES_LONG', $this->_postFields['state']);
        } else {
            // Create the 'state' form element.
            $state = new Moc10_Form_Element('text', 'state', $this->_postFields['state']);
            $state->setAttributes('size', ((!is_null($this->_postFields['mobile'])) ? '20' : '50'));
        }
        $state->setLabel(((!is_null($this->_postFields['mobile'])) ? $lang->__('State:') : $lang->__('State/Province/County:')));

        // Create the 'zip' form element.
        $zip = new Moc10_Form_Element('text', 'zip', $this->_postFields['zip']);
        $zip->setLabel(((!is_null($this->_postFields['mobile'])) ? $lang->__('Zip:') : $lang->__('Zip/Postal Code:')));
        $zip->setAttributes('size', ((!is_null($this->_postFields['mobile'])) ? '20' : '50'));

        // Create the 'country' form element.
        $country = new Moc10_Form_Element_Select('country', 'COUNTRIES', $this->_postFields['country']);
        $country->setLabel($lang->__('Country:'));

        // Create the 'phone' form element.
        $phone = new Moc10_Form_Element('text', 'phone', $this->_postFields['phone']);
        $phone->setLabel($lang->__('Phone:'));
        $phone->setAttributes('size', ((!is_null($this->_postFields['mobile'])) ? '20' : '50'));

        // Create the 'event_link' form element.
        $event_link = new Moc10_Form_Element('text', 'event_link', $this->_postFields['event_link']);
        $event_link->setLabel(((!is_null($this->_postFields['mobile'])) ? $lang->__('Link:') : $lang->__('Event Link:')));
        $event_link->setAttributes('size', ((!is_null($this->_postFields['mobile'])) ? '20' : '120'));

        // Create the 'event_desc' form element.
        $event_desc = new Moc10_Form_Element_Textarea('event_desc', $this->_postFields['event_desc']);
        $event_desc->setLabel(((!is_null($this->_postFields['mobile'])) ? $lang->__('Desc:') : $lang->__('Event Description:')));
        $event_desc->setAttributes('rows', ((!is_null($this->_postFields['mobile'])) ? '4' : '8'));
        $event_desc->setAttributes('cols', ((!is_null($this->_postFields['mobile'])) ? '30' : '120'));
        $event_desc->setAttributes('spellcheck', 'false');
        $event_desc->setAttributes('wrap', 'off');

        // Create the 'event_desc_format' form element.
        $event_desc_format = new Moc10_Form_Element_Select('event_desc_format', array('Text' => 'Text', 'HTML' => 'HTML'), $this->_postFields['event_desc_format']);
        $event_desc_format->setLabel(((!is_null($this->_postFields['mobile'])) ? $lang->__('Desc Format:') : $lang->__('Description Format:')));

        // Create the 'event_access' form element.
        $event_access = new Moc10_Form_Element_Select('event_access', array('Public' => $lang->__('Public'), 'Private' => $lang->__('Private')), $this->_postFields['event_access']);
        $event_access->setLabel($lang->__('Event Access:'));

        // Create the 'submit' form element.
        $submit = new Moc10_Form_Element('submit', 'submit', $lang->__('SAVE'));
        $submit->setAttributes('style', 'float: right;');

        // Create the 'event_id' form element.
        $event_id = new Moc10_Form_Element('hidden', 'event_id', $this->_postFields['event_id']);

        // Set whether it's a mobile form template or not.
        if (!is_null($this->_postFields['mobile'])) {
            $sess = Moc10_Session::getInstance();
            $submit->setAttributes('class', 'submitBtn');
            $site_id = new Moc10_Form_Element('hidden', 'site_id', $sess->cur_site_id);
            $this->setTemplate($this->_templates['mobile']);
        } else {
            $this->setAttributes('onsubmit', "return addEventFrm.addEventValidate();");
            $site_id = new Moc10_Form_Element_Select('site_id', $sitesAry['sites'], $this->_postFields['site_id']);
            $site_id->setLabel($lang->__('Add to Site:'));
            $submit->setAttributes('class', 'submitBtn');
            $site_id->setAttributes('onchange', "xmlhttp.getRequest('../core/process/check.section.php?site_id=' + this.value, addEventFrm.changeSection); return false;");
            $country->setAttributes('onchange', 'addEventFrm.changeState(this.value);');
            $event_title->setAttributes('style', 'width: 640px;');
            $event_desc->setAttributes('style', 'width: 640px;');
            $event_link->setAttributes('style', 'width: 640px;');
            $this->setTemplate($this->_templates['main']);
        }

        // Add the form element objects to the form.
        $this->addElements(array($type_id, $site_id, $section_id, $event_title, $start_month, $start_day, $start_year, $end_month, $end_day, $end_year, $recurrence1, $recurrence2, $recurrence3, $start_hour, $start_minute, $end_hour, $end_minute, $address1, $address2, $city, $state, $zip, $country, $phone, $event_link, $event_desc, $event_desc_format, $event_access, $event_id, $submit));

    }

    /**
     * Method to save the event data.
     *
     * @return void
     */
    public function saveData()
    {

        $sess = Moc10_Session::getInstance();

        if (($this->_postFields['start_month'] != '--') && ($this->_postFields['start_day'] != '--') && ($this->_postFields['start_year'] != '----')) {
            $event_start_date = $this->_postFields['start_year']. '-' . $this->_postFields['start_month'] . '-' . $this->_postFields['start_day'];
        } else {
            $event_start_date = '0000-00-00';
        }

        if (($this->_postFields['end_month'] != '--') && ($this->_postFields['end_day'] != '--') && ($this->_postFields['end_year'] != '----')) {
            $event_end_date = $this->_postFields['end_year'] . '-' . $this->_postFields['end_month'] . '-' . $this->_postFields['end_day'];
        } else {
            $event_end_date = '0000-00-00';
        }

        if (($this->_postFields['recurrence1'] != '--') && ($this->_postFields['recurrence2'] != '--')) {
            $event_recurrence = $this->_postFields['recurrence1'] . '+' . $this->_postFields['recurrence2'] . '+' . $this->_postFields['recurrence3'];
            $event_start_date = '0000-00-00';
            $event_end_date = '0000-00-00';
        } else {
            $event_recurrence = '';
        }

        if (($this->_postFields['end_hour'] != '--') && ($this->_postFields['end_minute'] != '--')) {
            $event_end_time = $this->_postFields['end_hour'] . ':' . $this->_postFields['end_minute'] . ':00';
        } else {
            $event_end_time = '00:00:00';
        }

        // Edit the existing event.
        if ($this->_postFields['event_id'] != 0) {

            $event = new Phire_Table_Events();
            $event->findById($this->_postFields['event_id']);

            $event->site_id = $this->_postFields['site_id'];
            $event->user_id = $sess->user_id;
            $event->type_id = $this->_postFields['type_id'];
            $event->section_id = $this->_postFields['section_id'];
            $event->event_title = $this->_postFields['event_title'];
            $event->event_start_date = $event_start_date;
            $event->event_end_date = $event_end_date;
            $event->event_recurrence = $event_recurrence;
            $event->event_start_time = $this->_postFields['start_hour'] . ':' . $this->_postFields['start_minute'] . ':00';
            $event->event_end_time = $event_end_time;
            $event->address1 = $this->_postFields['address1'];
            $event->address2 = $this->_postFields['address2'];
            $event->city = $this->_postFields['city'];
            $event->state = $this->_postFields['state'];
            $event->zip = $this->_postFields['zip'];
            $event->country = $this->_postFields['country'];
            $event->phone = $this->_postFields['phone'];
            $event->event_link = $this->_postFields['event_link'];
            $event->event_desc = $this->_postFields['event_desc'];
            $event->event_desc_format = $this->_postFields['event_desc_format'];
            $event->event_access = $this->_postFields['event_access'];

        // Else, save the new event.
        } else {

            $fields = array('site_id' => $this->_postFields['site_id'],
                            'type_id' => $this->_postFields['type_id'],
                            'user_id' => $sess->user_id,
                            'section_id' => $this->_postFields['section_id'],
                            'event_title' => $this->_postFields['event_title'],
                            'event_start_date' => $event_start_date,
                            'event_end_date' => $event_end_date,
                            'event_recurrence' => $event_recurrence,
                            'event_start_time' => $this->_postFields['start_hour'] . ':' . $this->_postFields['start_minute'] . ':00',
                            'event_end_time' => $event_end_time,
                            'address1' => $this->_postFields['address1'],
                            'address2' => $this->_postFields['address2'],
                            'city' => $this->_postFields['city'],
                            'state' => $this->_postFields['state'],
                            'zip' => $this->_postFields['zip'],
                            'country' => $this->_postFields['country'],
                            'phone' => $this->_postFields['phone'],
                            'event_link' => $this->_postFields['event_link'],
                            'event_desc' => $this->_postFields['event_desc'],
                            'event_desc_format' => $this->_postFields['event_desc_format'],
                            'event_access' => $this->_postFields['event_access']);

            $event = new Phire_Table_Events($fields);

        }

        $event->save();

    }


    /**
     * Method to set the post fields.
     *
     * @param  array $post
     * @return void
     */
    protected function _setFields($post = null)
    {

        if (!is_null($post)) {
            if ((!$_POST) && isset($post['event_id']) && ($post['event_id'] != 0)) {

                $event = new Phire_Table_Events();
                $event->findById($post['event_id']);

                $startDate = ($event->event_start_date != '0000-00-00') ? Moc10_String::setString($event->event_start_date)->split('-') : array('----', '--', '--');
                $endDate = ($event->event_end_date != '0000-00-00') ? Moc10_String::setString($event->event_end_date)->split('-') : array('----', '--', '--');
                $recAry = ($event->event_recurrence != '') ? Moc10_String::setString($event->event_recurrence)->split('+') : array(null, null);
                $startTime = Moc10_String::setString($event->event_start_time)->split(':');
                $endTime = ($event->event_end_time != '00:00:00') ? Moc10_String::setString($event->event_end_time)->split(':') : array('--', '--', '--');

                $this->_postFields['site_id'] = $event->site_id;
                $this->_postFields['type_id'] = $event->type_id;
                $this->_postFields['section_id'] = $event->section_id;
                $this->_postFields['event_title'] = (string)Moc10_String::setString($event->event_title)->strip()->html();
                $this->_postFields['address1'] = (string)Moc10_String::setString($event->address1)->strip()->html();
                $this->_postFields['address2'] = (string)Moc10_String::setString($event->address2)->strip()->html();
                $this->_postFields['city'] = (string)Moc10_String::setString($event->city)->strip()->html();
                $this->_postFields['state'] = (string)Moc10_String::setString($event->state)->strip()->html();
                $this->_postFields['zip'] = (string)Moc10_String::setString($event->zip)->strip()->html();
                $this->_postFields['country'] = (string)Moc10_String::setString($event->country)->strip()->html();
                $this->_postFields['phone'] = (string)Moc10_String::setString($event->phone)->strip()->html();
                $this->_postFields['event_link'] = (string)Moc10_String::setString($event->event_link)->strip()->html();
                $this->_postFields['event_desc'] = (string)Moc10_String::setString($event->event_desc)->strip()->html();
                $this->_postFields['event_desc_format'] = $event->event_desc_format;
                $this->_postFields['event_access'] = $event->event_access;
                $this->_postFields['start_month'] = $startDate[1];
                $this->_postFields['start_day'] = $startDate[2];
                $this->_postFields['start_year'] = $startDate[0];
                $this->_postFields['end_month'] = $endDate[1];
                $this->_postFields['end_day'] = $endDate[2];
                $this->_postFields['end_year'] = $endDate[0];
                $this->_postFields['recurrence1'] = (isset($recAry[0])) ? $recAry[0] : null;
                $this->_postFields['recurrence2'] = (isset($recAry[1])) ? $recAry[1] : null;
                $this->_postFields['recurrence3'] = (isset($recAry[2])) ? $recAry[2] : null;
                $this->_postFields['start_hour'] = $startTime[0];
                $this->_postFields['start_minute'] = $startTime[1];
                $this->_postFields['end_hour'] = $endTime[0];
                $this->_postFields['end_minute'] = $endTime[1];
                $this->_postFields['plugin'] = (isset($post['plugin'])) ? $post['plugin'] : null;
                $this->_postFields['mobile'] = (isset($post['mobile'])) ? $post['mobile'] : null;
                $this->_postFields['event_id'] = $event->event_id;

            } else {
                foreach ($post as $key => $value) {
                    if (array_key_exists($key, $this->_postFields)) {
                        $this->_postFields[$key] = (isset($post[$key])) ? $post[$key] : null;
                    }
                }
            }
        }

    }



    /**
     * Method to set the form templates.
     *
     * @return void
     */
    protected function _setTemplates()
    {

        $lang = new Phire_Language();
        $back = $lang->__('Back');
        $blue = $lang->__('Blue fields are required.');
        $cancel = $lang->__('CANCEL');

        if (!is_null($this->_postFields['plugin'])) {
            $plugin = "<input type=\"hidden\" name=\"plugin\" value=\"{$this->_postFields['plugin']}\" />";
            $plg_lnk = BASE_PATH . CONTENT_PATH . "/extensions/plugins/{$this->_postFields['plugin']}/?sys_path=" . BASE_PATH . SYS_PATH;
            $plg_cancel = "&plugin={$this->_postFields['plugin']}";
        } else {
            $plugin = null;
            $plg_lnk = './events.php';
            $plg_cancel = null;
        }

        // Define the main form template.
        $this->_templates['main'] = <<<FORMTEMP
            <table id="headerTable" cellpadding="0" cellspacing="0"><tr><td>&lt;&lt;&lt; <a class="orangeLink" href="{$plg_lnk}">{$back}</a></td></tr></table>
            <table id="dataAltTable" cellspacing="0" cellpadding="0">
                <tr class="grayHeader">
                    <td class="grayHeader">
                        &nbsp;
                    </td>
                </tr>
                <tr>
                    <td style="padding: 15px;">
                        <table id="entryTable" cellspacing="0" cellpadding="0">
                            <tr>
                                <td>
                                    &nbsp;
                                </td>
                                <td class="textRight">
                                    <h4 style="float: left;">{$blue}</h4>
                                    [{site_id_label}]
                                    [{site_id}]
                                    <span style="padding: 0 10px 0 10px;"> </span>
                                    [{section_id_label}]
                                    <span id="sectionDiv">
                                        [{section_id}]
                                    </span>
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{event_title_label}]
                                </td>
                                <td>
                                    [{event_title}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{start_month_label}]
                                </td>
                                <td>
                                    [{start_month}]
                                    [{start_day}]
                                    [{start_year}]
                                    to
                                    [{end_month}]
                                    [{end_day}]
                                    [{end_year}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{recurrence1_label}]
                                </td>
                                <td>
                                    [{recurrence1}]
                                    [{recurrence2}]
                                    [{recurrence3}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{start_hour_label}]
                                </td>
                                <td>
                                    [{start_hour}]
                                    [{start_minute}]
                                    to
                                    [{end_hour}]
                                    [{end_minute}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{type_id_label}]
                                </td>
                                <td>
                                    [{type_id}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{address1_label}]
                                </td>
                                <td>
                                    [{address1}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{address2_label}]
                                </td>
                                <td>
                                    [{address2}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{city_label}]
                                </td>
                                <td>
                                    [{city}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{state_label}]
                                </td>
                                <td id="stateTD">
                                    [{state}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{zip_label}]
                                </td>
                                <td>
                                    [{zip}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{country_label}]
                                </td>
                                <td>
                                    [{country}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{phone_label}]
                                </td>
                                <td>
                                    [{phone}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{event_link_label}]
                                </td>
                                <td>
                                    [{event_link}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{event_desc_label}]
                                </td>
                                <td>
                                    [{event_desc}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{event_desc_format_label}]
                                </td>
                                <td>
                                    [{event_desc_format}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{event_access_label}]
                                </td>
                                <td>
                                    [{event_access}]
                                </td>
                            </tr>
                            <tr>
                                <td colspan="2">
                                    <a style="margin: 0 0 0 10px; padding-top: 6px; height: 19px; font-size: 0.825em; float: right;" class="submitGrayBtn" href="../core/process/add.event.php?action=cancel{$plg_cancel}">{$cancel}</a> [{submit}] [{event_id}] {$plugin}
                                </td>
                            </tr>
                        </table>
                        <script type="text/javascript">
                            addEventFormInit();
                            var xmlhttp = new JaxXmlHttp();
                        </script>
                    </td>
                </tr>
            </table>
FORMTEMP;

        $mobile = (!is_null($this->_postFields['mobile'])) ? "<input type=\"hidden\" name=\"mobile\" value=\"true\" />" : null;

        // Define the mobile form template.
        $this->_templates['mobile'] = <<<FORMTEMP
            <table id="headerTable" cellpadding="0" cellspacing="0"><tr><td>&lt;&lt;&lt; <a class="orangeLink" href="./events.php">{$back}</a></td></tr></table>
            <table id="dataAltTable" cellspacing="0" cellpadding="0">
                <tr class="grayHeader" style="height; 16px;">
                    <td class="grayHeader" style="height; 16px;">
                        &nbsp;
                    </td>
                </tr>
                <tr>
                    <td style="padding: 5px;">
                        <table id="entryTable" cellspacing="0" cellpadding="0">
                            <tr>
                                <td>
                                    &nbsp;
                                </td>
                                <td>
                                    <h4>{$blue}</h4>
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{section_id_label}]
                                </td>
                                <td>
                                    [{section_id}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{event_title_label}]
                                </td>
                                <td>
                                    [{event_title}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{start_month_label}]
                                </td>
                                <td>
                                    [{start_month}]
                                    [{start_day}]
                                    [{start_year}]
                                    to<br />
                                    [{end_month}]
                                    [{end_day}]
                                    [{end_year}]
                                    or,
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{recurrence1_label}]
                                </td>
                                <td>
                                    [{recurrence1}]
                                    [{recurrence2}]
                                    [{recurrence3}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{start_hour_label}]
                                </td>
                                <td>
                                    [{start_hour}]
                                    [{start_minute}]
                                    to
                                    [{end_hour}]
                                    [{end_minute}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{type_id_label}]
                                </td>
                                <td>
                                    [{type_id}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{address1_label}]
                                </td>
                                <td>
                                    [{address1}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{address2_label}]
                                </td>
                                <td>
                                    [{address2}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{city_label}]
                                </td>
                                <td>
                                    [{city}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{state_label}]
                                </td>
                                <td>
                                    [{state}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{zip_label}]
                                </td>
                                <td>
                                    [{zip}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{country_label}]
                                </td>
                                <td>
                                    [{country}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{phone_label}]
                                </td>
                                <td>
                                    [{phone}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{event_link_label}]
                                </td>
                                <td>
                                    [{event_link}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{event_desc_label}]
                                </td>
                                <td>
                                    [{event_desc}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{event_desc_format_label}]
                                </td>
                                <td>
                                    [{event_desc_format}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{event_access_label}]
                                </td>
                                <td>
                                    [{event_access}]
                                </td>
                            </tr>
                            <tr>
                                <td colspan="2">
                                    <a style="float: right; margin: 0 0 0 5px; padding: 2px 3px 4px 3px; height: 10px; font-size: 0.9em;" class="submitBtnGray" href="../../core/process/add.event.php?action=cancel&mobile=true">{$cancel}</a> [{submit}] [{site_id}] {$mobile} [{event_id}]
                                </td>
                            </tr>
                        </table>
                    </td>
                </tr>
            </table>
FORMTEMP;

    }

}
