<?php
/**
 * Phire CMS
 *
 * LICENSE
 *
 * This source file is subject to the new BSD license that is bundled
 * with this package in the file LICENSE.TXT.
 * It is also available through the world-wide-web at this URL:
 * http://www.phirecms.org/LICENSE.TXT
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to info@phirecms.org so we can send you a copy immediately.
 *
 * @category   Phire
 * @package    Phire_Form
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 */

/**
 * Phire_Form_MemberProfile
 *
 * @category   Phire
 * @package    Phire_Form
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 * @version    1.1.2
 */

class Phire_Form_MemberProfile extends Moc10_Form
{

    /**
     * Post fields
     * @var string
     */
    public $fields = array('fname' => null,
                           'lname' => null,
                           'email' => null,
                           'phone' => null,
                           'address1' => null,
                           'address2' => null,
                           'city' => null,
                           'state' => null,
                           'zip' => null,
                           'country' => null,
                           'organization' => null,
                           'title' => null,
                           'birth_month' => null,
                           'birth_day' => null,
                           'birth_year' => null,
                           'gender' => null,
                           'username' => null,
                           'cur_username' => null,
                           'password1' => null,
                           'password2' => null,
                           'receive' => 'Yes',
                           'member_id' => null);

    /**
     * Capture setting
     * @var string
     */
    protected $_capture = null;

    /**
     * Business data capture setting
     * @var boolean
     */
    protected $_business = false;

    /**
     * Personal data capture setting
     * @var boolean
     */
    protected $_personal = false;

    /**
     * Create account setting
     * @var boolean
     */
    protected $_account = false;

    /**
     * Current form template
     * @var string
     */
    protected $_tmpl = null;

    /**
     * Member form elements
     * @var array
     */
    protected $_elems = array();

    /**
     * Language object
     * @var Phire_Language
     */
    protected $_lang = null;

    /**
     * Member form templates
     * @var array
     */
    protected $_tmpls = array('header'    => "            <style type=\"text/css\">\n                .radioPad {\n                    float: left;\n                    margin: 0;\n                    padding: 0 18px 0 4px;\n                }\n            </style>\n            <table id=\"memberTable\" cellspacing=\"0\" cellpadding=\"0\">\n",
                              'name'      => "                <tr>\n                    <td style=\"text-align: right; vertical-align: top;\">\n                        [{fname_label}]\n                    </td>\n                    <td>\n                        [{fname}]\n                    </td>\n                </tr>\n",
                              'full_name' => "                <tr>\n                    <td style=\"text-align: right; vertical-align: top;\">\n                        [{fname_label}]\n                    </td>\n                    <td>\n                        [{fname}]\n                    </td>\n                </tr>\n                <tr>\n                    <td style=\"text-align: right; vertical-align: top;\">\n                        [{lname_label}]\n                    </td>\n                    <td>\n                        [{lname}]\n                    </td>\n                </tr>\n",
                              'email'     => "                <tr>\n                    <td style=\"text-align: right; vertical-align: top;\">\n                        [{email_label}]\n                    </td>\n                    <td>\n                        [{email}]\n                    </td>\n                </tr>\n",
                              'phone'     => "                <tr>\n                    <td style=\"text-align: right; vertical-align: top;\">\n                        [{phone_label}]\n                    </td>\n                    <td>\n                        [{phone}]\n                    </td>\n                </tr>\n                <tr>\n                    <td colspan=\"2\">\n                        &nbsp;<br />\n                    </td>\n                </tr>\n",
                              'address'   => "                <tr>\n                    <td style=\"text-align: right; vertical-align: top;\">\n                        [{address1_label}]\n                    </td>\n                    <td>\n                        [{address1}]\n                    </td>\n                </tr>\n                <tr>\n                    <td style=\"text-align: right; vertical-align: top;\">\n                        [{address2_label}]\n                    </td>\n                    <td>\n                        [{address2}]\n                    </td>\n                </tr>\n",
                              'us'        => "                <tr>\n                    <td style=\"text-align: right; vertical-align: top;\">\n                        [{city_label}]\n                    </td>\n                    <td>\n                        <table cellpadding=\"0\" cellspacing=\"0\" style=\"margin: 0; padding: 0;\"><tr><td style=\"margin: 0; padding: 0 2px 0 0; vertical-align: top;\">[{city}]</td><td style=\"margin: 0; padding: 0 2px 0 2px; vertical-align: top;\">[{state}]</td><td style=\"margin: 0; padding: 0 2px 0 2px; vertical-align: top;\">[{zip}]</td></tr></table>\n                        [{country}]\n                    </td>\n                </tr>\n                <tr>\n                    <td colspan=\"2\">\n                        &nbsp;<br />\n                    </td>\n                </tr>\n",
                              'intl'      => "                <tr>\n                    <td style=\"text-align: right; vertical-align: top;\">\n                        [{city_label}]\n                    </td>\n                    <td>\n                        [{city}]\n                    </td>\n                </tr>\n                <tr>\n                    <td style=\"text-align: right; vertical-align: top;\">\n                        [{state_label}]\n                    </td>\n                    <td>\n                        [{state}]\n                    </td>\n                </tr>\n                <tr>\n                    <td style=\"text-align: right; vertical-align: top;\">\n                        [{zip_label}]\n                    </td>\n                    <td>\n                        [{zip}]\n                    </td>\n                </tr>\n                <tr>\n                    <td style=\"text-align: right; vertical-align: top;\">\n                        [{country_label}]\n                    </td>\n                    <td>\n                        [{country}]\n                    </td>\n                </tr>\n                <tr>\n                    <td colspan=\"2\">\n                        &nbsp;<br />\n                    </td>\n                </tr>\n",
                              'business'  => "                <tr>\n                    <td style=\"text-align: right; vertical-align: top;\">\n                        [{organization_label}]\n                    </td>\n                    <td>\n                        [{organization}]\n                    </td>\n                </tr>\n                <tr>\n                    <td style=\"text-align: right; vertical-align: top;\">\n                        [{title_label}]\n                    </td>\n                    <td>\n                        [{title}]\n                    </td>\n                </tr>\n                <tr>\n                    <td colspan=\"2\">\n                        &nbsp;<br />\n                    </td>\n                </tr>\n",
                              'personal'  => "               <tr>\n                   <td style=\"text-align: right; vertical-align: top;\">\n                       [{birth_month_label}]\n                   </td>\n                   <td>\n                       <table cellpadding=\"0\" cellspacing=\"0\" style=\"margin: 0; padding: 0;\">\n                           <tr>\n                               <td style=\"margin: 0; padding: 0 2px 0 0; vertical-align: top;\">\n                                   [{birth_month}]\n                               </td>\n                               <td style=\"margin: 0; padding: 0 2px 0 2px; vertical-align: top;\">\n                                   [{birth_day}]\n                               </td>\n                               <td style=\"margin: 0; padding: 0 2px 0 2px; vertical-align: top;\">\n                                   [{birth_year}]\n                               </td>\n                           </tr>\n                       </table>\n                   </td>\n               </tr>\n               <tr>\n                   <td style=\"text-align: right; vertical-align: top;\">\n                       [{gender_label}]\n                   </td>\n                   <td>\n                       [{gender}]\n                   </td>\n               </tr>\n                <tr>\n                    <td colspan=\"2\">\n                        &nbsp;<br />\n                    </td>\n                </tr>\n",
                              'username'  => "                <tr>\n                    <td style=\"text-align: right; vertical-align: top;\">\n                        [{username_label}]\n                    </td>\n                    <td>\n                        [{username}] [{cur_username}]\n                    </td>\n                </tr>\n                <tr>\n                    <td style=\"text-align: right; vertical-align: top;\">\n                        [{password1_label}]\n                    </td>\n                    <td>\n                        [{password1}]\n                    </td>\n                </tr>\n                <tr>\n                    <td style=\"text-align: right; vertical-align: top;\">\n                        [{password2_label}]\n                    </td>\n                    <td>\n                        [{password2}]\n                    </td>\n                </tr>\n                <tr>\n                    <td colspan=\"2\">\n                        &nbsp;<br />\n                    </td>\n                </tr>\n",
                              'footer'    => "                <tr>\n                    <td style=\"text-align: right; vertical-align: top;\">\n                        [{receive_label}]\n                    </td>\n                    <td>\n                        [{receive}]\n                    </td>\n                </tr>\n                <tr>\n                    <td>\n                        &nbsp;\n                    </td>\n                    <td>\n                        [{submit}] [{member_id}]\n                    </td>\n                </tr>\n            </table>");

    /**
     * Initialization method for the member registration form.
     *
     * @param  string $data
     * @param  array $post
     * @param  string|int $mid
     * @return void
     */
    public function init($data, $post = null, $mid = null)
    {

        $this->_lang = new Phire_Language();
        $this->_setFields($post, $mid);

        $this->setAttributes('id', 'memberForm');
        $dataAry = explode('+', $data);

        $this->_capture = $dataAry[0];
        if (in_array('Business', $dataAry)) {
            $this->_business = true;
        }
        if (in_array('Personal', $dataAry)) {
            $this->_personal = true;
        }
        if (in_array('Account', $dataAry)) {
            $this->_account = true;
        }

        // Set template based on the member data capture settings.
        switch ($this->_capture) {
            case 'Minimum':
                $this->setMinimum($this->fields['fname']);
                $this->_tmpl = $this->_tmpls['header'] . $this->_tmpls['name'] . $this->_tmpls['email'];
                $this->_tmpl = str_replace('[{email_label}]', '<strong>' . $this->_lang->__('Current Email:') . '</strong>', $this->_tmpl);
                $this->_tmpl = str_replace('[{email}]', $this->fields['email'], $this->_tmpl);
                break;

            case 'Basic':
                $this->setBasic($this->fields['fname'], $this->fields['lname'], $this->fields['phone']);
                $this->_tmpl = $this->_tmpls['header'] . $this->_tmpls['full_name'] . $this->_tmpls['email'] . $this->_tmpls['phone'];
                $this->_tmpl = str_replace('[{email_label}]', '<strong>' . $this->_lang->__('Current Email:') . '</strong>', $this->_tmpl);
                $this->_tmpl = str_replace('[{email}]', $this->fields['email'], $this->_tmpl);
                break;

            case 'US':
                $this->setUS($this->fields['fname'], $this->fields['lname'], $this->fields['phone'], $this->fields['address1'], $this->fields['address2'], $this->fields['city'], $this->fields['state'], $this->fields['zip'], $this->fields['country']);
                $this->_tmpl = $this->_tmpls['header'] . $this->_tmpls['full_name'] . $this->_tmpls['email'] . $this->_tmpls['phone'] . $this->_tmpls['address'] . $this->_tmpls['us'];
                $this->_tmpl = str_replace('[{email_label}]', '<strong>' . $this->_lang->__('Current Email:') . '</strong>', $this->_tmpl);
                $this->_tmpl = str_replace('[{email}]', $this->fields['email'], $this->_tmpl);
                break;

            case 'Intl':
                $this->setIntl($this->fields['fname'], $this->fields['lname'], $this->fields['phone'], $this->fields['address1'], $this->fields['address2'], $this->fields['city'], $this->fields['state'], $this->fields['zip'], $this->fields['country']);
                $this->_tmpl = $this->_tmpls['header'] . $this->_tmpls['full_name'] . $this->_tmpls['email'] . $this->_tmpls['phone'] . $this->_tmpls['address'] . $this->_tmpls['intl'];
                $this->_tmpl = str_replace('[{email_label}]', '<strong>' . $this->_lang->__('Current Email:') . '</strong>', $this->_tmpl);
                $this->_tmpl = str_replace('[{email}]', $this->fields['email'], $this->_tmpl);
                break;
        }

        if ($this->_business) {
            $this->setBusiness($this->fields['organization'], $this->fields['title']);
            $this->_tmpl .= $this->_tmpls['business'];
        }

        if ($this->_personal) {
            $this->setPersonal($this->fields['birth_month'], $this->fields['birth_day'], $this->fields['birth_year'], $this->fields['gender']);
            $this->_tmpl .= $this->_tmpls['personal'];
        }

        if ($this->_account) {
            $this->setAccount($this->fields['username'], $this->fields['cur_username'], $this->fields['password1'], $this->fields['password2']);
            $this->_tmpl .= $this->_tmpls['username'];
        }

        $this->setFooter($this->fields['receive'], $this->fields['member_id']);
        $this->_tmpl .= $this->_tmpls['footer'];

        // Set the form template and add the form element objects to the form.
        $this->setTemplate($this->_tmpl);
        $this->addElements($this->_elems);

    }

    /**
     * Method to create the minimum form elements.
     *
     * @param  string $fnm
     * @return void
     */
    public function setMinimum($fnm = null)
    {

        // Create the 'fname' form element.
        $fname = new Moc10_Form_Element('text', 'fname', $fnm);
        $fname->setLabel($this->_lang->__('Name:'));
        $fname->setAttributes('size', '40');
        $fname->setRequired(true);

        $this->_elems[] = $fname;

    }

    /**
     * Method to create the basic form elements.
     *
     * @param  string $fnm
     * @param  string $lnm
     * @param  string $ph
     * @return void
     */
    public function setBasic($fnm = null, $lnm = null, $ph = null)
    {

        // Create the 'fname' form element.
        $fname = new Moc10_Form_Element('text', 'fname', $fnm);
        $fname->setLabel($this->_lang->__('First Name:'));
        $fname->setAttributes('size', '40');
        $fname->setRequired(true);

        // Create the 'lname' form element.
        $lname = new Moc10_Form_Element('text', 'lname', $lnm);
        $lname->setLabel($this->_lang->__('Last Name:'));
        $lname->setAttributes('size', '40');
        $lname->setRequired(true);

        // Create the 'phone' form element.
        $phone = new Moc10_Form_Element('text', 'phone', $ph);
        $phone->setLabel($this->_lang->__('Phone:'));
        $phone->setAttributes('size', '40');
        $phone->setRequired(true);

        $this->_elems[] = $fname;
        $this->_elems[] = $lname;
        $this->_elems[] = $phone;

    }

    /**
     * Method to create the form elements to capture a US address.
     *
     * @param  string $fnm
     * @param  string $lnm
     * @param  string $ph
     * @param  string $add1
     * @param  string $add2
     * @param  string $cty
     * @param  string $st
     * @param  string $zp
     * @return void
     */
    public function setUS($fnm = null, $lnm = null, $ph = null, $add1 = null, $add2 = null, $cty = null, $st = null, $zp = null, $cnty = 'US')
    {

        // Create the 'fname' form element.
        $fname = new Moc10_Form_Element('text', 'fname', $fnm);
        $fname->setLabel($this->_lang->__('First Name:'));
        $fname->setAttributes('size', '40');
        $fname->setRequired(true);

        // Create the 'lname' form element.
        $lname = new Moc10_Form_Element('text', 'lname', $lnm);
        $lname->setLabel($this->_lang->__('Last Name:'));
        $lname->setAttributes('size', '40');
        $lname->setRequired(true);

        // Create the 'phone' form element.
        $phone = new Moc10_Form_Element('text', 'phone', $ph);
        $phone->setLabel($this->_lang->__('Phone:'));
        $phone->setAttributes('size', '40');
        $phone->setRequired(true);

        // Create the 'address1' form element.
        $address1 = new Moc10_Form_Element('text', 'address1', $add1);
        $address1->setLabel($this->_lang->__('Address 1:'));
        $address1->setAttributes('size', '40');
        $address1->setRequired(true);

        // Create the 'address2' form element.
        $address2 = new Moc10_Form_Element('text', 'address2', $add2);
        $address2->setLabel($this->_lang->__('Address 2:'));
        $address2->setAttributes('size', '40');

        // Create the 'city' form element.
        $city = new Moc10_Form_Element('text', 'city', $cty);
        $city->setLabel($this->_lang->__('City') . ', ' . $this->_lang->__('State/Province/County') . ' &amp; ' . $this->_lang->__('Zip/Postal Code:'));
        $city->setAttributes('size', '40');
        $city->setRequired(true);

        // Create the 'state' form element.
        $state = new Moc10_Form_Element_Select('state', 'US_STATES_SHORT', $st);
        $state->addValidator('NotEqual', true, '--', $this->_lang->__('Please enter a state.'));
        $state->setRequired(true);

        // Create the 'zip' form element.
        $zip = new Moc10_Form_Element('text', 'zip', $zp);
        $zip->setAttributes('size', '10');
        $zip->setRequired(true);

        // Create the 'country' form element.
        $country = new Moc10_Form_Element('hidden', 'country', $cnty);

        $this->_elems[] = $fname;
        $this->_elems[] = $lname;
        $this->_elems[] = $phone;
        $this->_elems[] = $address1;
        $this->_elems[] = $address2;
        $this->_elems[] = $city;
        $this->_elems[] = $state;
        $this->_elems[] = $zip;
        $this->_elems[] = $country;

    }

    /**
     * Method to create the form elements to capture an International address.
     *
     * @param  string $fnm
     * @param  string $lnm
     * @param  string $ph
     * @param  string $add1
     * @param  string $add2
     * @param  string $cty
     * @param  string $st
     * @param  string $zp
     * @param  string $cnty
     * @return void
     */
    public function setIntl($fnm = null, $lnm = null, $ph = null, $add1 = null, $add2 = null, $cty = null, $st = null, $zp = null, $cnty = null)
    {

        // Create the 'fname' form element.
        $fname = new Moc10_Form_Element('text', 'fname', $fnm);
        $fname->setLabel($this->_lang->__('First Name:'));
        $fname->setAttributes('size', '40');
        $fname->setRequired(true);

        // Create the 'lname' form element.
        $lname = new Moc10_Form_Element('text', 'lname', $lnm);
        $lname->setLabel($this->_lang->__('Last Name:'));
        $lname->setAttributes('size', '40');
        $lname->setRequired(true);

        // Create the 'phone' form element.
        $phone = new Moc10_Form_Element('text', 'phone', $ph);
        $phone->setLabel($this->_lang->__('Phone:'));
        $phone->setAttributes('size', '40');
        $phone->setRequired(true);

        // Create the 'address1' form element.
        $address1 = new Moc10_Form_Element('text', 'address1', $add1);
        $address1->setLabel($this->_lang->__('Address 1:'));
        $address1->setAttributes('size', '40');
        $address1->setRequired(true);

        // Create the 'address2' form element.
        $address2 = new Moc10_Form_Element('text', 'address2', $add2);
        $address2->setLabel($this->_lang->__('Address 2:'));
        $address2->setAttributes('size', '40');

        // Create the 'city' form element.
        $city = new Moc10_Form_Element('text', 'city', $cty);
        $city->setLabel($this->_lang->__('City:'));
        $city->setAttributes('size', '40');
        $city->setRequired(true);

        // Create the 'state' form element.
        $state = new Moc10_Form_Element('text', 'state', $st);
        $state->setLabel($this->_lang->__('State/Province/County:'));
        $state->setAttributes('size', '40');
        $state->setRequired(true);

        // Create the 'zip' form element.
        $zip = new Moc10_Form_Element('text', 'zip', $zp);
        $zip->setLabel($this->_lang->__('Zip/Postal Code:'));
        $zip->setAttributes('size', '20');
        $zip->setRequired(true);

        // Create the 'country' form element.
        $country = new Moc10_Form_Element_Select('country', 'COUNTRIES', $cnty);
        $country->setLabel('Country:');
        $country->addValidator('NotEqual', true, '------', $this->_lang->__('Please select a country.'));
        $country->setRequired(true);

        $this->_elems[] = $fname;
        $this->_elems[] = $lname;
        $this->_elems[] = $phone;
        $this->_elems[] = $address1;
        $this->_elems[] = $address2;
        $this->_elems[] = $city;
        $this->_elems[] = $state;
        $this->_elems[] = $zip;
        $this->_elems[] = $country;

    }

    /**
     * Method to create the business form elements.
     *
     * @param  string $org
     * @param  string $tle
     * @return void
     */
    public function setBusiness($org = null, $tle = null)
    {

        // Create the 'organization' form element.
        $organization = new Moc10_Form_Element('text', 'organization', $org);
        $organization->setLabel($this->_lang->__('Company/Organization:'));
        $organization->setAttributes('size', '40');
        $organization->setRequired(true);

        // Create the 'title' form element.
        $title = new Moc10_Form_Element('text', 'title', $tle);
        $title->setLabel($this->_lang->__('Title:'));
        $title->setAttributes('size', '40');
        $title->setRequired(true);

        $this->_elems[] = $organization;
        $this->_elems[] = $title;

    }

    /**
     * Method to create the personal form elements.
     *
     * @param  string $b_mth
     * @param  string $b_day
     * @param  string $b_year
     * @param  string $gen
     * @return void
     */
    public function setPersonal($b_mth = null, $b_day = null, $b_year = null, $gen = null)
    {

        $months = array('--' => '--------',
                        '01' => $this->_lang->__('January'),
                        '02' => $this->_lang->__('February'),
                        '03' => $this->_lang->__('March'),
                        '04' => $this->_lang->__('April'),
                        '05' => $this->_lang->__('May'),
                        '06' => $this->_lang->__('June'),
                        '07' => $this->_lang->__('July'),
                        '08' => $this->_lang->__('August'),
                        '09' => $this->_lang->__('September'),
                        '10' => $this->_lang->__('October'),
                        '11' => $this->_lang->__('November'),
                        '12' => $this->_lang->__('December'));

        // Create the 'birth_month' form element.
        $birth_month = new Moc10_Form_Element_Select('birth_month', $months, $b_mth);
        $birth_month->setLabel($this->_lang->__('Birth Date:'));
        $birth_month->addValidator('NotEqual', true, '--', $this->_lang->__('Please enter a month.'));
        $birth_month->setRequired(true);

        // Create the 'birth_day' form element.
        $birth_day = new Moc10_Form_Element_Select('birth_day', 'DAYS_OF_MONTH', $b_day);
        $birth_day->addValidator('NotEqual', true, '--', $this->_lang->__('Please enter a day.'));

        // Create the 'birth_year' form element.
        $birth_year = new Moc10_Form_Element_Select('birth_year', 'YEAR_' . date('Y') . '_1900', $b_year);
        $birth_year->addValidator('NotEqual', true, '----', $this->_lang->__('Please enter a year.'));

        // Create the 'gender' form element.
        $gender = new Moc10_Form_Element_Select('gender', array('----' => '----', 'Male' => $this->_lang->__('Male'), 'Female' => $this->_lang->__('Female')), $gen);
        $gender->setLabel($this->_lang->__('Gender:'));
        $gender->addValidator('NotEqual', true, '----', $this->_lang->__('Please enter your gender.'));
        $gender->setRequired(true);

        $this->_elems[] = $birth_month;
        $this->_elems[] = $birth_day;
        $this->_elems[] = $birth_year;
        $this->_elems[] = $gender;

    }

    /**
     * Method to create the account form elements.
     *
     * @param  string $usr
     * @param  string $cur_usr
     * @param  string $pw1
     * @param  string $pw2
     * @return void
     */
    public function setAccount($usr = null, $cur_usr = null, $pw1 = null, $pw2 = null)
    {

        // Create the 'username' form element.
        $username = new Moc10_Form_Element('text', 'username', $usr);
        $username->setLabel($this->_lang->__('Username:'));
        $username->setAttributes('size', '40');
        $username->setRequired(true);

        // Create the 'cur_username' form element.
        $cur_username = new Moc10_Form_Element('hidden', 'cur_username', (is_null($cur_usr) ? $usr : $cur_usr));

        // If the form has been submitted, validate the username.
        if ((!is_null($usr)) && ($usr != $cur_usr)) {
            $dupe_member = new Phire_Table_Members();
            $dupe_member->findBy('username', $usr);
            if (isset($dupe_member->member_id)) {
                $username->addValidator('NotEqual', true, $dupe_member->username, $this->_lang->__('That username already exists.'));
            }
        }

        // Create the 'password1' form element.
        $password1 = new Moc10_Form_Element('password', 'password1', $pw1);
        $password1->setLabel($this->_lang->__('Change Password:'));
        $password1->setAttributes('size', '20');

        // Create the 'password2' form element.
        $password2 = new Moc10_Form_Element('password', 'password2', $pw2);
        $password2->setLabel($this->_lang->__('Re-type New Password:'));
        $password2->setAttributes('size', '20');

        // If the form has been submitted, validate the passwords.
        if (!is_null($pw1)) {
            $password1->addValidator('LengthGT', true, 5);
            $password2->addValidator('Equal', true, $pw1, $this->_lang->__('The passwords do not match.'));
        }

        $this->_elems[] = $username;
        $this->_elems[] = $cur_username;
        $this->_elems[] = $password1;
        $this->_elems[] = $password2;

    }

    /**
     * Method to create the footer form elements.
     *
     * @param  string $rec
     * @param  string|int $mid
     * @return void
     */
    public function setFooter($rec = 'Yes', $mid = 0)
    {

        // Create the 'receive' form element.
        $receive = new Moc10_Form_Element_Radio('receive', array('Yes' => $this->_lang->__('Yes'), 'No' => $this->_lang->__('No')), $rec);
        $receive->setLabel($this->_lang->__('Receive Updates:'));

        // Create the 'member_id' form element.
        $member_id = new Moc10_Form_Element('hidden', 'member_id', $mid);

        // Create the 'submit' form element.
        $submit = new Moc10_Form_Element('submit', 'submit', $this->_lang->__('UPDATE'));
        $submit->setAttributes('class', 'submitBtn');

        $this->_elems[] = $receive;
        $this->_elems[] = $member_id;
        $this->_elems[] = $submit;

    }

    /**
     * Method to set the fields.
     *
     * @param  array $post
     * @param  string|int $mid
     * @return void
     */
    protected function _setFields($post = null, $mid = null)
    {

        if (!is_null($post)) {

            $this->fields['fname'] = (isset($post['fname'])) ? (string)Moc10_String::setString($post['fname'])->escape()->striptags() : null;
            $this->fields['lname'] = (isset($post['lname'])) ? (string)Moc10_String::setString($post['lname'])->escape()->striptags() : null;
            $this->fields['email'] = (isset($post['email'])) ? (string)Moc10_String::setString($post['email'])->escape()->striptags() : null;
            $this->fields['phone'] = (isset($post['phone'])) ? (string)Moc10_String::setString($post['phone'])->escape()->striptags() : null;
            $this->fields['address1'] = (isset($post['address1'])) ? (string)Moc10_String::setString($post['address1'])->escape()->striptags() : null;
            $this->fields['address2'] = (isset($post['address2'])) ? (string)Moc10_String::setString($post['address2'])->escape()->striptags() : null;
            $this->fields['city'] = (isset($post['city'])) ? (string)Moc10_String::setString($post['city'])->escape()->striptags() : null;
            $this->fields['state'] = (isset($post['state'])) ? (string)Moc10_String::setString($post['state'])->escape()->striptags() : null;
            $this->fields['zip'] = (isset($post['zip'])) ? (string)Moc10_String::setString($post['zip'])->escape()->striptags() : null;
            $this->fields['country'] = (isset($post['country'])) ? (string)Moc10_String::setString($post['country'])->escape()->striptags() : null;
            $this->fields['organization'] = (isset($post['organization'])) ? (string)Moc10_String::setString($post['organization'])->escape()->striptags() : null;
            $this->fields['title'] = (isset($post['title'])) ? (string)Moc10_String::setString($post['title'])->escape()->striptags() : null;
            $this->fields['birth_month'] = (isset($post['birth_month'])) ? (string)Moc10_String::setString($post['birth_month'])->escape()->striptags() : null;
            $this->fields['birth_day'] = (isset($post['birth_day'])) ? (string)Moc10_String::setString($post['birth_day'])->escape()->striptags() : null;
            $this->fields['birth_year'] = (isset($post['birth_year'])) ? (string)Moc10_String::setString($post['birth_year'])->escape()->striptags() : null;
            $this->fields['gender'] = (isset($post['gender'])) ? (string)Moc10_String::setString($post['gender'])->escape()->striptags() : null;
            $this->fields['username'] = (isset($post['username'])) ? (string)Moc10_String::setString($post['username'])->escape()->striptags() : null;
            $this->fields['cur_username'] = (isset($post['cur_username'])) ? (string)Moc10_String::setString($post['cur_username'])->escape()->striptags() : null;
            $this->fields['password1'] = (isset($post['password1'])) ? (string)Moc10_String::setString($post['password1'])->escape()->striptags() : null;
            $this->fields['password2'] = (isset($post['password2'])) ? (string)Moc10_String::setString($post['password2'])->escape()->striptags() : null;
            $this->fields['receive'] = (isset($post['receive'])) ? (string)Moc10_String::setString($post['receive'])->escape()->striptags() : 'Yes';
            $this->fields['member_id'] = (isset($post['member_id'])) ? (string)Moc10_String::setString($post['member_id'])->escape()->striptags() : null;

        } else {

            $member = new Phire_Table_Members();
            $member->findById($mid);

            if ($member->birth_date == '0000-00-00') {
                $birth_month = null;
                $birth_day = null;
                $birth_year = null;
            } else {
                $birthDateAry = explode('-', $member->birth_date);
                $birth_month = $birthDateAry[1];
                $birth_day = $birthDateAry[2];
                $birth_year = $birthDateAry[0];
            }

            $this->fields['fname'] = ($member->fname != '') ? (string)Moc10_String::setString($member->fname)->strip()->html() : null;
            $this->fields['lname'] = ($member->lname != '') ? (string)Moc10_String::setString($member->lname)->strip()->html() : null;
            $this->fields['email'] = $member->email;
            $this->fields['phone'] = ($member->phone != '') ? (string)Moc10_String::setString($member->phone)->strip()->html() : null;
            $this->fields['address1'] = ($member->address1 != '') ? (string)Moc10_String::setString($member->address1)->strip()->html() : null;
            $this->fields['address2'] = ($member->address2 != '') ? (string)Moc10_String::setString($member->address2)->strip()->html() : null;
            $this->fields['city'] = ($member->city != '') ? (string)Moc10_String::setString($member->city)->strip()->html() : null;
            $this->fields['state'] = ($member->state != '') ? (string)Moc10_String::setString($member->state)->strip()->html() : null;
            $this->fields['zip'] = ($member->zip != '') ? (string)Moc10_String::setString($member->zip)->strip()->html() : null;
            $this->fields['country'] = ($member->country != '') ? (string)Moc10_String::setString($member->country)->strip()->html() : null;
            $this->fields['organization'] = ($member->organization != '') ? (string)Moc10_String::setString($member->organization)->strip()->html() : null;
            $this->fields['title'] = ($member->title != '') ? (string)Moc10_String::setString($member->title)->strip()->html() : null;
            $this->fields['birth_month'] = $birth_month;
            $this->fields['birth_day'] = $birth_day;
            $this->fields['birth_year'] = $birth_year;
            $this->fields['gender'] = ($member->gender != '') ? $member->gender : null;
            $this->fields['username'] = $member->username;
            $this->fields['password1'] = null;
            $this->fields['password2'] = null;
            $this->fields['receive'] = $member->receive_updates;
            $this->fields['member_id'] = $member->member_id;

        }

    }

}
