<?php
/**
 * Phire CMS
 *
 * LICENSE
 *
 * This source file is subject to the new BSD license that is bundled
 * with this package in the file LICENSE.TXT.
 * It is also available through the world-wide-web at this URL:
 * http://www.phirecms.org/LICENSE.TXT
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to info@phirecms.org so we can send you a copy immediately.
 *
 * @category   Phire
 * @package    Phire_Form
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 */

/**
 * Phire_Form_Setup
 *
 * @category   Phire
 * @package    Phire_Form
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 * @version    1.1.2
 */

class Phire_Form_Setup extends Moc10_Form
{

    /**
     * User object
     * @var Phire_Table_Users
     */
    public $user = null;

    /**
     * $_POST fields
     * @var array
     */
    protected $_postFields = array('fname' => null,
                                   'lname' => null,
                                   'email1' => null,
                                   'email2' => null,
                                   'username' => null,
                                   'password1' => null,
                                   'password2' => null,
                                   'password_encoding' => null,
                                   'send_creds' => null);

    /**
     * Initialization method for the setup form.
     *
     * @param  array $post
     * @return void
     */
    public function init($post = null)
    {

        $lang = new Phire_Language();

        $this->_setFields($post);

        $this->setAttributes('id', 'setupForm');
        $this->setAttributes('onsubmit', "return setupFrm.setupValidate();");

        // Create the 'fname' form element.
        $fname = new Moc10_Form_Element('text', 'fname', $this->_postFields['fname']);
        $fname->setLabel($lang->__('First Name:'));
        $fname->setAttributes('size', '40');
        $fname->setRequired(true);

        // Create the 'lname' form element.
        $lname = new Moc10_Form_Element('text', 'lname', $this->_postFields['lname']);
        $lname->setLabel($lang->__('Last Name:'));
        $lname->setAttributes('size', '40');
        $lname->setRequired(true);

        // Create the 'email1' form element.
        $email1 = new Moc10_Form_Element('text', 'email1', $this->_postFields['email1']);
        $email1->setLabel($lang->__('Email:'));
        $email1->addValidator('Email');
        $email1->setAttributes('size', '40');
        $email1->setRequired(true);

        // Create the 'email2' form element.
        $email2 = new Moc10_Form_Element('text', 'email2', $this->_postFields['email2']);
        $email2->setLabel($lang->__('Confirm Email:'));
        $email2->addValidator('Email');
        $email2->addValidator('Equal', true, $this->_postFields['email1'], 'The emails do not match.');
        $email2->setAttributes('size', '40');
        $email2->setRequired(true);

        // Create the 'username' form element.
        $username = new Moc10_Form_Element('text', 'username', $this->_postFields['username']);
        $username->setLabel($lang->__('Username:'));
        $username->addValidator('AlphaNum');
        $username->addValidator('LengthGT', true, 3);
        $username->setAttributes('size', '40');
        $username->setRequired(true);

        // Create the 'password1' form element.
        $password1 = new Moc10_Form_Element('password', 'password1', $this->_postFields['password1']);
        $password1->setLabel($lang->__('Password:'));
        $password1->addValidator('LengthGT', true, 5);
        $password1->setAttributes('size', '20');
        $password1->setRequired(true);

        // Create the 'password2' form element.
        $password2 = new Moc10_Form_Element('password', 'password2', $this->_postFields['password2']);
        $password2->setLabel($lang->__('Re-type Password:'));
        $password2->addValidator('LengthGT', true, 5);
        $password2->addValidator('Equal', true, $this->_postFields['password1'], 'The passwords do not match.');
        $password2->setAttributes('size', '20');
        $password2->setRequired(true);

        // Create the 'password_encoding' form element.
        $password_encoding = new Moc10_Form_Element_Select('password_encoding', array('SHA1' => 'SHA1', 'MD5' => 'MD5', 'Off' => $lang->__('None (Not recommended)')), $this->_postFields['password_encoding']);
        $password_encoding->setLabel($lang->__('Password Encoding:'));
        $password_encoding->setRequired(true);

        // Create the 'send_creds' form element.
        $send_creds = new Moc10_Form_Element_Checkbox('send_creds', array('send_creds' => $lang->__('Send credentials to user?')), $this->_postFields['send_creds']);

        // Create the 'submit' form element.
        $submit = new Moc10_Form_Element('submit', 'submit', $lang->__('SAVE'));
        $submit->setAttributes('class', 'submitBtn');

        $setup = $lang->__('Set Up The Initial System User.');
        $blue = $lang->__('Blue fields are required.');
        $user = $lang->__('Username must be alphanumeric and at least 4 characters in length.');
        $pass = $lang->__('Password must be at least 6 characters in length.');

        // Define the form template.
        $tmpl = <<<FORMTEMP
            <table id="setupTable">
                <tr>
                    <td>
                        &nbsp;
                    </td>
                    <td>
                        <h4>{$setup}</h4>
                        <em style="color: #008aff;">{$blue}</em>
                    </td>
                </tr>
                <tr>
                    <td class="textTopRight">
                        [{fname_label}]
                    </td>
                    <td>
                        [{fname}]
                    </td>
                </tr>
                <tr>
                    <td class="textTopRight">
                        [{lname_label}]
                    </td>
                    <td>
                        [{lname}]
                    </td>
                </tr>
                <tr>
                    <td colspan="2">
                        &nbsp;<br />
                    </td>
                </tr>
                <tr>
                    <td class="textTopRight">
                        [{email1_label}]
                    </td>
                    <td>
                        [{email1}]
                    </td>
                </tr>
                <tr>
                    <td class="textTopRight">
                        [{email2_label}]
                    </td>
                    <td>
                        [{email2}]
                    </td>
                </tr>
                <tr>
                <tr>
                    <td>
                        &nbsp;
                    </td>
                    <td>
                        <em>{$user}</em><br />
                    </td>
                </tr>
                <tr>
                    <td class="textTopRight">
                        [{username_label}]
                    </td>
                    <td>
                        [{username}]
                    </td>
                </tr>
                <tr>
                    <td>
                        &nbsp;
                    </td>
                    <td>
                        <em>{$pass}</em><br />
                    </td>
                </tr>
                <tr>
                    <td class="textTopRight">
                        [{password1_label}]
                    </td>
                    <td>
                        [{password1}]
                    </td>
                </tr>
                <tr>
                    <td class="textTopRight">
                        [{password2_label}]
                    </td>
                    <td>
                        [{password2}]
                    </td>
                </tr>
                <tr>
                    <td class="textTopRight">
                        [{password_encoding_label}]
                    </td>
                    <td>
                        [{password_encoding}]
                    </td>
                </tr>
                <tr>
                    <td class="textTopRight">
                        &nbsp;
                    </td>
                    <td>
                        [{send_creds}]
                    </td>
                </tr>
                <tr>
                    <td>
                        &nbsp;
                    </td>
                    <td>
                        [{submit}]
                    </td>
                </tr>
            </table>
            <script type="text/javascript">
                setupFormInit();
                setupFrm.fo.fname.focus();
            </script>
FORMTEMP;

        // Set the form template and add the form element objects to the form.
        $this->setTemplate($tmpl);
        $this->addElements(array($fname, $lname, $email1, $email2, $username, $password1, $password2, $password_encoding, $send_creds, $submit));

    }

    /**
     * Method to save the system set-up data.
     *
     * @return void
     */
    public function saveData()
    {

        $lang = new Phire_Language();
        $org_password = $this->_postFields['password1'];

        if ($this->_postFields['password_encoding'] != 'Off') {
            $config = new Phire_Table_Config();
            $config->findById('user_password_encoding');
            $config->value = $this->_postFields['password_encoding'];
            $config->save();
            $password = ($this->_postFields['password_encoding'] == 'SHA1') ? sha1($this->_postFields['password1']) : md5($this->_postFields['password1']);
        } else {
            $password = $this->_postFields['password1'];
        }

        // Initialize and save the default user.
        $userFields = array('fname' => $this->_postFields['fname'],
                            'lname' => $this->_postFields['lname'],
                            'email' => $this->_postFields['email1'],
                            'username' => $this->_postFields['username'],
                            'password' => $password,
                            'verified' => 'Yes',
                            'access' => 'Admin',
                            'allowed_sites' => '2001',
                            'last_login' => '0000-00-00 00:00:00',
                            'last_login_from' => '',
                            'last_ip' => '',
                            'failed_login_attempts' => 0);

        $this->user = new Phire_Table_Users($userFields);
        $this->user->save();

        if (isset($this->_postFields['send_creds'])) {

            $rcpt = array(array('name' => $this->_postFields['fname'] . ' ' . $this->_postFields['lname'],
                                'email' => $this->user->email,
                                'username' => $this->user->username,
                                'password' => $org_password,
                                'login_link' => 'http://' . $_SERVER['HTTP_HOST'] . BASE_PATH . SYS_PATH . '/'));

            $message = "[{name}],\n\n" . $lang->__('Your user account for the Phire CMS has been created. Your credentials for the Phire CMS are:') . "\n\n" . $lang->__('Username:') . " [{username}]\n" . $lang->__('Password:') . " [{password}]\n\n" . $lang->__('You can log in here:') . "\n[{login_link}]\n\n" . $lang->__('Thank You,') . "\n\n" . $lang->__('The Phire CMS Team') . "\n\n";

            $noreply = 'noreply@' . ((stripos($_SERVER['HTTP_HOST'], 'www.') !== false) ? str_replace('www.', '', $_SERVER['HTTP_HOST']) : $_SERVER['HTTP_HOST']);

            $mail = new Moc10_Mail($rcpt, null, $lang->__('Phire CMS User Account Created'));
            $mail->setHeaders(array('From' => array($noreply, $noreply),
                                    'Reply-To' => array($noreply, $noreply)));

            $mail->setText($message);
            $mail->init();
            $mail->send();

        }

        // Initialize and save the default site.
        $siteFields = array('site_domain' => $_SERVER['HTTP_HOST'],
                            'site_docroot' => $_SERVER['DOCUMENT_ROOT'],
                            'site_email' => $this->user->email,
                            'default_type_id' => 3001,
                            'default_charset' => 4001,
                            'default_title' => 'My Default Site',
                            'default_author' => 'Default Author',
                            'default_keywords' => 'default, keywords',
                            'default_desc' => 'This is my default site.',
                            'default_robots' => 5001,
                            'default_template_id' => 0,
                            'default_404' => "    <p>We're sorry. That page was not found. [{site_email}]</p>\n",
                            'default_date_format' => 'M j Y',
                            'default_time_format' => 'g:i A',
                            'title_separator' => ' | ',
                            'large_action' => 'Resize',
                            'large_size' => 640,
                            'medium_action' => 'Crop',
                            'medium_size' => 120,
                            'small_action' => 'Crop',
                            'small_size' => 60,
                            'allowed_image_formats' => 'jpg|jpe|jpeg|gif|png',
                            'image_max_size' => '25 MB',
                            'allowed_file_formats' => 'any',
                            'file_max_size' => '25 MB',
                            'allowed_content_types' => '3001|3002|3003|3004|3005|3006|3007',
                            'comment_allow' => 'Yes',
                            'anon_comments' => 'Yes',
                            'comment_approval' => 'On',
                            'input_captcha' => 'Off',
                            'member_allow' => 'No',
                            'member_enable_login' => 'No',
                            'member_enable_registration' => 'No',
                            'member_registration' => 'Minimum',
                            'member_verification' => 'Off',
                            'member_approval' => 'Off',
                            'member_ssl_connection' => 'No',
                            'member_password_encoding' => 'Off',
                            'member_redirects' => '',
                            'spam_rules' => '',
                            'feed_type' => 'RSS',
                            'feed_limit' => 0,
                            'page_caching' => 'Off',
                            'open_authoring' => 'On',
                            'site_pagination_limit' => 25,
                            'site_pagination_range' => 10,
                            'use_ssl_connection' => 'No',
                            'site_live' => 'Yes');

        $site = new Phire_Table_Sites($siteFields);
        $site->save();

        // Initialize and save the default home page template.
        $home_template = new Moc10_File($_SERVER['DOCUMENT_ROOT'] . BASE_PATH . CONTENT_PATH . '/extensions/themes/default-1.0/index.html');
        $tmplFields = array('site_id' => $site->site_id,
                            'theme_id' => 18001,
                            'type_id' => 3001,
                            'template_name' => 'Home Page Template',
                            'template' => $home_template->read(),
                            'mobile_template' => '');

        $tmpl = new Phire_Table_Templates($tmplFields);
        $tmpl->save();

        // Initialize and save the default home page.
        $pageFields = array('site_id' => $site->site_id,
                            'user_id' => $this->user->user_id,
                            'section_id' => 0,
                            'template_id' => $tmpl->template_id,
                            'page_url' => '/',
                            'page_charset' => 4001,
                            'page_title' => 'Welcome!',
                            'page_author' => 'Default Author',
                            'page_keywords' => 'default, keywords',
                            'page_desc' => 'This is the home page of my default site.',
                            'page_robots' => 5001,
                            'page_content' => "    <p>\n        Welcome to my website, powered by the Phire CMS. Learn more <a href=\"[{base_path}]/about\">about us</a>.\n    </p>\n    <h4>YouTube Most Viewed</h4>\n[{feed_9002}]",
                            'page_filter' => 'None',
                            'page_tags' => '',
                            'page_access' => 'Public',
                            'page_requests' => 0,
                            'comments_allowed' => 'No',
                            'feed' => 'Yes',
                            'force_ssl_connection' => 'No',
                            'published' => 'Yes',
                            'created' => date('Y-m-d H:i:s'),
                            'updated' => '0000-00-00 00:00:00',
                            'expire' => '0000-00-00 00:00:00');

        $page = new Phire_Table_Pages($pageFields);
        $page->save();

        // Initialize and save the default sub page template.
        $sub_template = new Moc10_File($_SERVER['DOCUMENT_ROOT'] . BASE_PATH . CONTENT_PATH . '/extensions/themes/default-1.0/sub.html');
        $tmplFields = array('site_id' => $site->site_id,
                            'theme_id' => 18001,
                            'type_id' => 3001,
                            'template_name' => 'Sub Page Template',
                            'template' => $sub_template->read(),
                            'mobile_template' => '');

        $tmpl = new Phire_Table_Templates($tmplFields);
        $tmpl->save();

        $site->default_template_id = $tmpl->template_id;
        $site->save();

        // Initialize and save the default sub page.
        $pageFields = array('site_id' => $site->site_id,
                            'user_id' => $this->user->user_id,
                            'section_id' => 0,
                            'template_id' => $tmpl->template_id,
                            'page_url' => '/about',
                            'page_charset' => 4001,
                            'page_title' => 'About',
                            'page_author' => 'Default Author',
                            'page_keywords' => 'about, default, keywords',
                            'page_desc' => 'This is the about page of my default site.',
                            'page_robots' => 5001,
                            'page_content' => "    <p>\n        This is an example of a sub page. You could learn more about me here. <a href=\"[{base_path}]/\">Return home</a>.\n    </p>",
                            'page_filter' => 'None',
                            'page_tags' => '',
                            'page_access' => 'Public',
                            'page_requests' => 0,
                            'comments_allowed' => 'Yes',
                            'feed' => 'Yes',
                            'force_ssl_connection' => 'No',
                            'published' => 'Yes',
                            'created' => date('Y-m-d H:i:s'),
                            'updated' => '0000-00-00 00:00:00',
                            'expire' => '0000-00-00 00:00:00');

        $page = new Phire_Table_Pages($pageFields);
        $page->save();

        // Initialize and save the default sub page.
        $pageFields = array('site_id' => $site->site_id,
                            'user_id' => $this->user->user_id,
                            'section_id' => 0,
                            'template_id' => $tmpl->template_id,
                            'page_url' => '/contact',
                            'page_charset' => 4001,
                            'page_title' => 'Contact',
                            'page_author' => 'Default Author',
                            'page_keywords' => 'contact, default, keywords',
                            'page_desc' => 'This is the contact page of my default site.',
                            'page_robots' => 5001,
                            'page_content' => "    <p>\n        This is an example of another sub page. My contact info could go here. <a href=\"[{base_path}]/\">Return home</a>.\n    </p>",
                            'page_filter' => 'None',
                            'page_tags' => '',
                            'page_access' => 'Public',
                            'page_requests' => 0,
                            'comments_allowed' => 'No',
                            'feed' => 'Yes',
                            'force_ssl_connection' => 'No',
                            'published' => 'Yes',
                            'created' => date('Y-m-d H:i:s'),
                            'updated' => '0000-00-00 00:00:00',
                            'expire' => '0000-00-00 00:00:00');

        $page = new Phire_Table_Pages($pageFields);
        $page->save();

        // Initialize and save the default header template.
        $header_template = new Moc10_File($_SERVER['DOCUMENT_ROOT'] . BASE_PATH . CONTENT_PATH . '/extensions/themes/default-1.0/header.html');
        $tmplFields = array('site_id' => $site->site_id,
                            'theme_id' => 18001,
                            'type_id' => 3001,
                            'template_name' => 'Header Template',
                            'template' => $header_template->read(),
                            'mobile_template' => '');

        $tmpl = new Phire_Table_Templates($tmplFields);
        $tmpl->save();

        // Initialize and save the default footer template.
        $footer_template = new Moc10_File($_SERVER['DOCUMENT_ROOT'] . BASE_PATH . CONTENT_PATH . '/extensions/themes/default-1.0/footer.html');
        $tmplFields = array('site_id' => $site->site_id,
                            'theme_id' => 18001,
                            'type_id' => 3001,
                            'template_name' => 'Footer Template',
                            'template' => $footer_template->read(),
                            'mobile_template' => '');

        $tmpl = new Phire_Table_Templates($tmplFields);
        $tmpl->save();

    }

    /**
     * Method to set the post fields.
     *
     * @param  array $post
     * @return void
     */
    protected function _setFields($post = null)
    {

        if (!is_null($post)) {
            foreach ($post as $key => $value) {
                if (array_key_exists($key, $this->_postFields)) {
                    $this->_postFields[$key] = (isset($post[$key])) ? $post[$key] : null;
                }
            }
        }

    }

}
