<?php
/**
 * Phire CMS
 *
 * LICENSE
 *
 * This source file is subject to the new BSD license that is bundled
 * with this package in the file LICENSE.TXT.
 * It is also available through the world-wide-web at this URL:
 * http://www.phirecms.org/LICENSE.TXT
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to info@phirecms.org so we can send you a copy immediately.
 *
 * @category   Phire
 * @package    Phire_Parser
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 */

/**
 * Phire_Parser_Template
 *
 * @category   Phire
 * @package    Phire_Parser
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 * @version    1.1.2
 */

class Phire_Parser_Template
{

    /**
     * Template RegEx
     * @var string
     */
    protected $_regex = '/\[\{template_(\d*|\w*)\}\]/';

    /**
     * Content to evaluate
     * @var string
     */
    protected $_content = null;

    /**
     * Constructor
     *
     * Instantiate the template parser object.
     *
     * @param  string $content
     * @return void
     */
    public function __construct($content, $id = null)
    {

        // Perform a preg_match_all to look for any template tags within the content, then parse the content.
        $this->_content = $this->_parse($content, $id);

    }

    /**
     * Static method to instantiate the feed parser object
     * and return the parsed string.
     *
     * @param  string $cont
     * @param  string $i
     * @return Phire_Parser_Template
     */
    public static function init($cont, $i = null)
    {

        return new self($cont, $i);

    }

    /**
     * Set content within the content property.
     *
     * @param  string $subject
     * @param  string $replace
     * @return void
     */
    public function setContent($subject, $replace)
    {

        $this->_content = str_replace($subject, $replace, $this->_content);

    }

    /**
     * Get content within the content property.
     *
     * @return string
     */
    public function getContent()
    {

        return $this->_content;

    }

    /**
     * Renders any feed elements within the content.
     *
     * @param  string $cont
     * @param  string $id
     * @return void
     */
    protected function _parse($cont, $id = null)
    {

        $mob = new Moc10_Session_Mobile();
        $matches = array();
        preg_match_all($this->_regex, $cont, $matches);

        if (isset($matches[0][0])) {

            foreach ($matches[0] as $value) {

                $tid = str_replace('[{template_', '', $value);
                $tid = str_replace('}]', '', $tid);

                if ($tid != $id) {
                    $tmpl = new Phire_Table_Templates();

                    if (is_numeric($tid)) {
                        $tmpl->findById($tid);
                    } else {
                        $tmpl->findBy('template_name', $tid);
                        if (!isset($tmpl->template_id)) {
                            $tmpl->findBy('template_name', str_replace('_', ' ', $tid));
                        }
                    }

                    if (isset($tmpl->template_id)) {
                        $template = (($mob->isMobile !== false) && ($tmpl->mobile_template != '')) ? $this->_parse($tmpl->mobile_template, $tid) : $this->_parse($tmpl->template, $tid);
                        $cont = str_replace($value, $template, $cont);
                    } else {
                        $cont = str_replace($value, '', $cont);
                    }
                } else {
                    $cont = str_replace($value, '', $cont);
                }

            }

        }

        return $cont;

    }

}
