<?php

/**
 * Phire Install Themes
 *
 * @category   Phire
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 * @version    1.1.2
 */

$error = false;
$sort = 'theme_id';

require_once '../../bootstrap.php';
require_once 'check.themes.php';

// Install new themes if detected.
if (count($newThemes) > 0) {

    // Check if the ZIP extension is installed.
    if (!class_exists('ZipArchive')) {
        header('Location: ' . BASE_PATH . SYS_PATH . '/extensions/themes.php?error=nozip');
    } else {

        // Check to make sure the files are ZIP files.
        foreach ($newThemes as $fle) {
            $zipFile = new Moc10_File($fle[1] . $fle[2]);
            if ($zipFile->ext != 'zip') {
                header('Location: ' . BASE_PATH . SYS_PATH . '/extensions/themes.php?error=file');
            }
        }

        // Iterate through each theme file.
        foreach ($newThemes as $fle) {

            // Extract the ZIP file to the correct folder.
            $zipFile = new Moc10_File($fle[1] . $fle[2]);
            $zip = new ZipArchive();

            if ($zip->open($zipFile->fullpath) === true) {
                $zip->extractTo($fle[1]);
                $zip->close();
            }

            if (file_exists($fle[1] . '/' . $zipFile->filename) && file_exists($fle[1] . '/' . $zipFile->filename . '/' . $zipFile->filename . '.txt')) {

                // Read the theme config file.
                $themeTxt = new Moc10_File($fle[1] . '/' . $zipFile->filename . '/' . $zipFile->filename . '.txt');
                $output = $themeTxt->read();

                $theme = substr($output, (strpos($output, '@theme') + 6));
                $theme = trim(substr($theme, 0, (strpos($theme, "\n"))));

                $file = substr($output, (strpos($output, '@file') + 5));
                $file = trim(substr($file, 0, (strpos($file, "\n"))));

                $folder = substr($output, (strpos($output, '@folder') + 7));
                $folder = trim(substr($folder, 0, (strpos($folder, "\n"))));

                $author = substr($output, (strpos($output, '@author') + 7));
                $author = trim(substr($author, 0, (strpos($author, "\n"))));

                $version = substr($output, (strpos($output, '@version') + 8));
                $version = trim(substr($version, 0, (strpos($version, "\n"))));

                // Save the new theme in the DB.
                $thFields = array('site_id' => $fle[0],
                                  'theme_name' => $theme,
                                  'templates' => '',
                                  'theme_file' => $file,
                                  'theme_folder' => $folder,
                                  'theme_author' => $author,
                                  'theme_version' => $version);
                $new_theme = new Phire_Table_Themes($thFields);
                $new_theme->save();

                // Add the theme's templates to the system.
                $tmpls = substr($output, (strpos($output, '*/') + 6));

                $tmplAry = explode("\n", $tmpls);
                $templates = array();
                $tmplIds = array();

                if (count($tmplAry) > 0) {

                    foreach ($tmplAry as $value) {
                        $templates[] = explode(':', $value);
                    }

                    $new_template_folder = new Moc10_File_Dir($fle[1] . $folder, true, true);
                    $new_template_folder->setMode(0777);

                    foreach ($new_template_folder->files as $file) {
                        chmod($file, 0777);
                    }

                    // Initialize and save each of the templates.
                    foreach ($templates as $tmpl) {

                        if (trim($tmpl[1]) != '') {

                            $new_template = new Moc10_File($fle[1] . $folder . '/' . trim($tmpl[1]));

                            if (isset($tmpl[2])) {
                                $new_mobile_template = new Moc10_File($fle[1] . $folder . '/' . trim($tmpl[2]));
                                $mob_tmpl = $new_mobile_template->read();
                            } else {
                                $mob_tmpl = '';
                            }

                            $contentType = new Phire_Table_ContentTypes();
                            $contentType->findBy('type', $new_template->mime);

                            $tmplFields = array('site_id' => $fle[0],
                                                'theme_id' => $new_theme->theme_id,
                                                'type_id' => ((isset($contentType->type_id)) ? $contentType->type_id : 3001),
                                                'template_name' => trim($tmpl[0]),
                                                'template' => $new_template->read(),
                                                'mobile_template' => $mob_tmpl);


                            $tmp = new Phire_Table_Templates($tmplFields);
                            $tmp->save();

                            $tmplIds[] = $tmp->template_id;

                        }

                    }

                }

                // Save the new templates to the theme in the DB.
                $new_theme->templates = implode('|', $tmplIds);
                $new_theme->save();

            } else {
                $error = true;
            }

        }

        header('Location: ' . BASE_PATH . SYS_PATH . '/extensions/themes.php?action=' . (($error) ? 'error' : 'saved'));

    }

} else {
    header('Location: ' . BASE_PATH . SYS_PATH . '/extensions/themes.php');
}

?>